@@ -12,11 +12,11 @@ import (
 const (
 	giteaTokenTitle = `Gitea API token`
 	giteaTokenHelp  = `
-If you have an API token for Gitea,
-and want to ship branches from the CLI,
-please enter it now.
+Git Town can update pull requests and ship branches on gitea for you.
+To enable this, please enter a gitea API token.
+More info at https://www.git-town.com/preferences/gitea-token.
 
-It's okay to leave this empty.
+If you leave this empty, Git Town will not use the gitea API.
 
 `
 )
