@@ -12,11 +12,11 @@ import (
 const (
 	gitLabTokenTitle = `GitLab API token`
 	gitLabTokenHelp  = `
-If you have an API token for GitLab,
-and want to ship branches from the CLI,
-please enter it now.
+Git Town can update merge requests and ship branches on GitLab for you.
+To enable this, please enter a GitLab API token.
+More info at https://www.git-town.com/preferences/gitlab-token.
 
-It's okay to leave this empty.
+If you leave this empty, Git Town will not use the GitLab API.
 
 `
 )
