@@ -1,7 +1,7 @@
 package flags
 
 import (
-	"github.com/git-town/git-town/v15/internal/config/configdomain"
+	"github.com/git-town/git-town/v16/internal/config/configdomain"
 	"github.com/spf13/cobra"
 )
 
@@ -13,7 +13,7 @@ const (
 // type-safe access to the CLI arguments of type configdomain.Pending
 func Pending() (AddFunc, ReadPendingFlagFunc) {
 	addFlag := func(cmd *cobra.Command) {
-		cmd.PersistentFlags().BoolP(pendingLong, pendingShort, false, "display just the name of the pending Git Town command")
+		cmd.Flags().BoolP(pendingLong, pendingShort, false, "display just the name of the pending Git Town command")
 	}
 	readFlag := func(cmd *cobra.Command) configdomain.Pending {
 		value, err := cmd.Flags().GetBool(pendingLong)
