@@ -3,10 +3,10 @@ package print
 import (
 	"fmt"
 
-	"github.com/git-town/git-town/v15/internal/cli/colors"
-	"github.com/git-town/git-town/v15/internal/config/configdomain"
-	"github.com/git-town/git-town/v15/internal/gohacks"
-	"github.com/git-town/git-town/v15/internal/messages"
+	"github.com/git-town/git-town/v16/internal/cli/colors"
+	"github.com/git-town/git-town/v16/internal/config/configdomain"
+	"github.com/git-town/git-town/v16/internal/gohacks"
+	"github.com/git-town/git-town/v16/internal/messages"
 )
 
 func Footer(verbose configdomain.Verbose, commandsCount gohacks.Counter, finalMessages []string) {
@@ -19,7 +19,7 @@ func Footer(verbose configdomain.Verbose, commandsCount gohacks.Counter, finalMe
 
 // NoFinalMessages can be used by callers of PrintFooter to indicate
 // that the command has no final messages to print.
-var NoFinalMessages = []string{} //nolint:gochecknoglobals
+var NoFinalMessages []string //nolint:gochecknoglobals
 
 // Messages prints the given messages to the user.
 func Messages(messages []string) {
