@@ -6,6 +6,7 @@ import (
 	"github.com/git-town/git-town/v16/internal/cmd/debug"
 	"github.com/git-town/git-town/v16/internal/cmd/ship"
 	"github.com/git-town/git-town/v16/internal/cmd/status"
+	"github.com/git-town/git-town/v16/internal/cmd/sync"
 )
 
 // Execute runs the Cobra stack.
@@ -21,7 +22,9 @@ func Execute() error {
 	rootCmd.AddCommand(debug.RootCmd())
 	rootCmd.AddCommand(diffParentCommand())
 	rootCmd.AddCommand(hackCmd())
+	rootCmd.AddCommand(deleteCommand())
 	rootCmd.AddCommand(killCommand())
+	rootCmd.AddCommand(mergeCommand())
 	rootCmd.AddCommand(newPullRequestCommand())
 	rootCmd.AddCommand(observeCmd())
 	rootCmd.AddCommand(offlineCmd())
@@ -30,13 +33,14 @@ func Execute() error {
 	rootCmd.AddCommand(prependCommand())
 	rootCmd.AddCommand(prototypeCmd())
 	rootCmd.AddCommand(renameBranchCommand())
+	rootCmd.AddCommand(renameCommand())
 	rootCmd.AddCommand(repoCommand())
 	rootCmd.AddCommand(status.RootCommand())
 	rootCmd.AddCommand(setParentCommand())
 	rootCmd.AddCommand(ship.Cmd())
 	rootCmd.AddCommand(skipCmd())
 	rootCmd.AddCommand(switchCmd())
-	rootCmd.AddCommand(syncCmd())
+	rootCmd.AddCommand(sync.Cmd())
 	rootCmd.AddCommand(undoCmd())
 	return rootCmd.Execute()
 }
