@@ -1,3 +1,4 @@
+// Package debug implements Git Town's hidden "debug" command.
 package debug
 
 import (
@@ -11,6 +12,8 @@ func RootCmd() *cobra.Command {
 		Hidden: true,
 	}
 	debugCommand.AddCommand(enterAliases())
+	debugCommand.AddCommand(enterBitbucketAppPassword())
+	debugCommand.AddCommand(enterBitbucketUsername())
 	debugCommand.AddCommand(enterCreatePrototypeBranches())
 	debugCommand.AddCommand(enterDefaultBranch())
 	debugCommand.AddCommand(enterFeatureRegex())
