@@ -10,6 +10,7 @@ import (
 	"github.com/git-town/git-town/v16/internal/cli/flags"
 	"github.com/git-town/git-town/v16/internal/cli/print"
 	"github.com/git-town/git-town/v16/internal/cmd/cmdhelpers"
+	"github.com/git-town/git-town/v16/internal/cmd/sync"
 	"github.com/git-town/git-town/v16/internal/config"
 	"github.com/git-town/git-town/v16/internal/config/configdomain"
 	"github.com/git-town/git-town/v16/internal/execute"
@@ -166,6 +167,10 @@ type createFeatureBranchArgs struct {
 }
 
 func determineHackData(args []string, repo execute.OpenRepoResult, detached configdomain.Detached, dryRun configdomain.DryRun, prototype configdomain.Prototype, verbose configdomain.Verbose) (data hackData, exit bool, err error) {
+	preFetchBranchSnapshot, err := repo.Git.BranchesSnapshot(repo.Backend)
+	if err != nil {
+		return data, false, err
+	}
 	dialogTestInputs := components.LoadTestInputs(os.Environ())
 	previousBranch := repo.Git.PreviouslyCheckedOutBranch(repo.Backend)
 	targetBranches := gitdomain.NewLocalBranchNames(args...)
@@ -214,7 +219,7 @@ func determineHackData(args []string, repo execute.OpenRepoResult, detached conf
 	if err != nil {
 		return data, false, err
 	}
-	branchesAndTypes := repo.UnvalidatedConfig.Config.Value.BranchesAndTypes(localBranchNames)
+	branchesAndTypes := repo.UnvalidatedConfig.UnvalidatedBranchesAndTypes(localBranchNames)
 	validatedConfig, exit, err := validate.Config(validate.ConfigArgs{
 		Backend:            repo.Backend,
 		BranchesAndTypes:   branchesAndTypes,
@@ -227,7 +232,7 @@ func determineHackData(args []string, repo execute.OpenRepoResult, detached conf
 		LocalBranches:      localBranchNames,
 		RepoStatus:         repoStatus,
 		TestInputs:         dialogTestInputs,
-		Unvalidated:        repo.UnvalidatedConfig,
+		Unvalidated:        NewMutable(&repo.UnvalidatedConfig),
 	})
 	if err != nil || exit {
 		return data, exit, err
@@ -235,7 +240,7 @@ func determineHackData(args []string, repo execute.OpenRepoResult, detached conf
 	if !shouldCreateBranch {
 		data = Right[appendFeatureData, convertToFeatureData](convertToFeatureData{
 			config:         validatedConfig,
-			targetBranches: validatedConfig.Config.BranchesAndTypes(branchesToValidate),
+			targetBranches: validatedConfig.BranchesAndTypes(branchesToValidate),
 		})
 		return data, false, nil
 	}
@@ -254,11 +259,11 @@ func determineHackData(args []string, repo execute.OpenRepoResult, detached conf
 	if branchesSnapshot.Branches.HasMatchingTrackingBranchFor(targetBranch) {
 		return data, false, fmt.Errorf(messages.BranchAlreadyExistsRemotely, targetBranch)
 	}
-	branchNamesToSync := gitdomain.LocalBranchNames{validatedConfig.Config.MainBranch}
+	branchNamesToSync := gitdomain.LocalBranchNames{validatedConfig.ValidatedConfigData.MainBranch}
 	if detached {
-		branchNamesToSync = validatedConfig.Config.RemovePerennials(branchNamesToSync)
+		branchNamesToSync = validatedConfig.RemovePerennials(branchNamesToSync)
 	}
-	branchesToSync, err := branchesToSync(branchNamesToSync, branchesSnapshot, repo, validatedConfig.Config.MainBranch)
+	branchesToSync, err := sync.BranchesToSync(branchNamesToSync, branchesSnapshot, repo, validatedConfig.ValidatedConfigData.MainBranch)
 	if err != nil {
 		return data, false, err
 	}
@@ -271,7 +276,8 @@ func determineHackData(args []string, repo execute.OpenRepoResult, detached conf
 		dryRun:                    dryRun,
 		hasOpenChanges:            repoStatus.OpenChanges,
 		initialBranch:             initialBranch,
-		newBranchParentCandidates: gitdomain.LocalBranchNames{validatedConfig.Config.MainBranch},
+		newBranchParentCandidates: gitdomain.LocalBranchNames{validatedConfig.ValidatedConfigData.MainBranch},
+		preFetchBranchInfos:       preFetchBranchSnapshot.Branches,
 		previousBranch:            previousBranch,
 		prototype:                 prototype,
 		remotes:                   remotes,
@@ -289,14 +295,17 @@ func convertToFeatureBranch(args convertToFeatureBranchArgs) error {
 	for branchName, branchType := range args.makeFeatureData.targetBranches {
 		switch branchType {
 		case configdomain.BranchTypeContributionBranch:
-			err = args.config.RemoveFromContributionBranches(branchName)
+			err = args.config.NormalConfig.RemoveFromContributionBranches(branchName)
 		case configdomain.BranchTypeObservedBranch:
-			err = args.config.RemoveFromObservedBranches(branchName)
+			err = args.config.NormalConfig.RemoveFromObservedBranches(branchName)
 		case configdomain.BranchTypeParkedBranch:
-			err = args.config.RemoveFromParkedBranches(branchName)
+			err = args.config.NormalConfig.RemoveFromParkedBranches(branchName)
 		case configdomain.BranchTypePrototypeBranch:
-			err = args.config.RemoveFromPrototypeBranches(branchName)
-		case configdomain.BranchTypeFeatureBranch, configdomain.BranchTypeMainBranch, configdomain.BranchTypePerennialBranch:
+			err = args.config.NormalConfig.RemoveFromPrototypeBranches(branchName)
+		case
+			configdomain.BranchTypeFeatureBranch,
+			configdomain.BranchTypeMainBranch,
+			configdomain.BranchTypePerennialBranch:
 			panic(fmt.Sprintf("unchecked branch type: %s", branchType))
 		}
 		if err != nil {
@@ -330,7 +339,11 @@ type convertToFeatureBranchArgs struct {
 func validateConvertToFeatureData(data convertToFeatureData) error {
 	for branchName, branchType := range data.targetBranches {
 		switch branchType {
-		case configdomain.BranchTypeContributionBranch, configdomain.BranchTypeObservedBranch, configdomain.BranchTypeParkedBranch, configdomain.BranchTypePrototypeBranch:
+		case
+			configdomain.BranchTypeContributionBranch,
+			configdomain.BranchTypeObservedBranch,
+			configdomain.BranchTypeParkedBranch,
+			configdomain.BranchTypePrototypeBranch:
 			return nil
 		case configdomain.BranchTypeFeatureBranch:
 			return fmt.Errorf(messages.HackBranchIsAlreadyFeature, branchName)
