@@ -12,11 +12,12 @@ import (
 )
 
 func newPullRequestCommand() *cobra.Command {
-	addVerboseFlag, readVerboseFlag := flags.Verbose()
-	addDryRunFlag, readDryRunFlag := flags.DryRun()
-	addTitleFlag, readTitleFlag := flags.ProposalTitle()
 	addBodyFlag, readBodyFlag := flags.ProposalBody()
 	addBodyFileFlag, readBodyFileFlag := flags.ProposalBodyFile()
+	addDetachedFlag, readDetachedFlag := flags.Detached()
+	addDryRunFlag, readDryRunFlag := flags.DryRun()
+	addTitleFlag, readTitleFlag := flags.ProposalTitle()
+	addVerboseFlag, readVerboseFlag := flags.Verbose()
 	cmd := cobra.Command{
 		Use:     "new-pull-request",
 		GroupID: "basic",
@@ -26,16 +27,17 @@ func newPullRequestCommand() *cobra.Command {
 		Long:    cmdhelpers.Long(proposeDesc, fmt.Sprintf(proposeHelp, configdomain.KeyHostingPlatform, configdomain.KeyHostingOriginHostname)),
 		RunE: func(cmd *cobra.Command, _ []string) error {
 			printDeprecationNotice()
-			result := executePropose(readDryRunFlag(cmd), readVerboseFlag(cmd), readTitleFlag(cmd), readBodyFlag(cmd), readBodyFileFlag(cmd))
+			result := executePropose(readDetachedFlag(cmd), readDryRunFlag(cmd), readVerboseFlag(cmd), readTitleFlag(cmd), readBodyFlag(cmd), readBodyFileFlag(cmd))
 			printDeprecationNotice()
 			return result
 		},
 	}
-	addDryRunFlag(&cmd)
-	addVerboseFlag(&cmd)
-	addTitleFlag(&cmd)
 	addBodyFlag(&cmd)
 	addBodyFileFlag(&cmd)
+	addDetachedFlag(&cmd)
+	addDryRunFlag(&cmd)
+	addTitleFlag(&cmd)
+	addVerboseFlag(&cmd)
 	return &cmd
 }
 
