@@ -11,6 +11,7 @@ import (
 	"github.com/git-town/git-town/v16/internal/cli/print"
 	"github.com/git-town/git-town/v16/internal/cmd/cmdhelpers"
 	"github.com/git-town/git-town/v16/internal/cmd/ship"
+	"github.com/git-town/git-town/v16/internal/cmd/sync"
 	"github.com/git-town/git-town/v16/internal/config"
 	"github.com/git-town/git-town/v16/internal/config/configdomain"
 	"github.com/git-town/git-town/v16/internal/execute"
@@ -18,7 +19,6 @@ import (
 	"github.com/git-town/git-town/v16/internal/hosting"
 	"github.com/git-town/git-town/v16/internal/hosting/hostingdomain"
 	"github.com/git-town/git-town/v16/internal/messages"
-	"github.com/git-town/git-town/v16/internal/sync"
 	"github.com/git-town/git-town/v16/internal/undo/undoconfig"
 	"github.com/git-town/git-town/v16/internal/validate"
 	fullInterpreter "github.com/git-town/git-town/v16/internal/vm/interpreter/full"
@@ -43,7 +43,7 @@ func prependCommand() *cobra.Command {
 	addVerboseFlag, readVerboseFlag := flags.Verbose()
 	cmd := cobra.Command{
 		Use:     "prepend <branch>",
-		GroupID: "lineage",
+		GroupID: "stack",
 		Args:    cobra.ExactArgs(1),
 		Short:   prependDesc,
 		Long:    cmdhelpers.Long(prependDesc, prependHelp),
@@ -120,6 +120,7 @@ type prependData struct {
 	hasOpenChanges      bool
 	initialBranch       gitdomain.LocalBranchName
 	newParentCandidates gitdomain.LocalBranchNames
+	preFetchBranchInfos gitdomain.BranchInfos
 	previousBranch      Option[gitdomain.LocalBranchName]
 	proposal            Option[hostingdomain.Proposal]
 	prototype           configdomain.Prototype
@@ -129,6 +130,10 @@ type prependData struct {
 }
 
 func determinePrependData(args []string, repo execute.OpenRepoResult, detached configdomain.Detached, dryRun configdomain.DryRun, prototype configdomain.Prototype, verbose configdomain.Verbose) (data prependData, exit bool, err error) {
+	prefetchBranchSnapshot, err := repo.Git.BranchesSnapshot(repo.Backend)
+	if err != nil {
+		return data, false, err
+	}
 	dialogTestInputs := components.LoadTestInputs(os.Environ())
 	repoStatus, err := repo.Git.RepoStatus(repo.Backend)
 	if err != nil {
@@ -173,7 +178,7 @@ func determinePrependData(args []string, repo execute.OpenRepoResult, detached c
 	if err != nil {
 		return data, false, err
 	}
-	branchesAndTypes := repo.UnvalidatedConfig.Config.Value.BranchesAndTypes(branchesSnapshot.Branches.LocalBranches().Names())
+	branchesAndTypes := repo.UnvalidatedConfig.UnvalidatedBranchesAndTypes(branchesSnapshot.Branches.LocalBranches().Names())
 	validatedConfig, exit, err := validate.Config(validate.ConfigArgs{
 		Backend:            repo.Backend,
 		BranchesAndTypes:   branchesAndTypes,
@@ -186,25 +191,25 @@ func determinePrependData(args []string, repo execute.OpenRepoResult, detached c
 		LocalBranches:      localBranches,
 		RepoStatus:         repoStatus,
 		TestInputs:         dialogTestInputs,
-		Unvalidated:        repo.UnvalidatedConfig,
+		Unvalidated:        NewMutable(&repo.UnvalidatedConfig),
 	})
 	if err != nil || exit {
 		return data, exit, err
 	}
-	branchNamesToSync := validatedConfig.Config.Lineage.BranchAndAncestors(initialBranch)
+	branchNamesToSync := validatedConfig.NormalConfig.Lineage.BranchAndAncestors(initialBranch)
 	if detached {
-		branchNamesToSync = validatedConfig.Config.RemovePerennials(branchNamesToSync)
+		branchNamesToSync = validatedConfig.RemovePerennials(branchNamesToSync)
 	}
-	branchesToSync, err := branchesToSync(branchNamesToSync, branchesSnapshot, repo, validatedConfig.Config.MainBranch)
+	branchesToSync, err := sync.BranchesToSync(branchNamesToSync, branchesSnapshot, repo, validatedConfig.ValidatedConfigData.MainBranch)
 	if err != nil {
 		return data, false, err
 	}
-	parentOpt := validatedConfig.Config.Lineage.Parent(initialBranch)
+	parentOpt := validatedConfig.NormalConfig.Lineage.Parent(initialBranch)
 	parent, hasParent := parentOpt.Get()
 	if !hasParent {
 		return data, false, fmt.Errorf(messages.SetParentNoFeatureBranch, branchesSnapshot.Active)
 	}
-	parentAndAncestors := validatedConfig.Config.Lineage.BranchAndAncestors(parent)
+	parentAndAncestors := validatedConfig.NormalConfig.Lineage.BranchAndAncestors(parent)
 	slices.Reverse(parentAndAncestors)
 	proposalOpt := ship.FindProposal(connector, initialBranch, parentOpt)
 	return prependData{
@@ -219,6 +224,7 @@ func determinePrependData(args []string, repo execute.OpenRepoResult, detached c
 		hasOpenChanges:      repoStatus.OpenChanges,
 		initialBranch:       initialBranch,
 		newParentCandidates: parentAndAncestors,
+		preFetchBranchInfos: prefetchBranchSnapshot.Branches,
 		previousBranch:      previousBranch,
 		proposal:            proposalOpt,
 		prototype:           prototype,
@@ -232,39 +238,42 @@ func prependProgram(data prependData) program.Program {
 	prog := NewMutable(&program.Program{})
 	if !data.hasOpenChanges {
 		sync.BranchesProgram(data.branchesToSync, sync.BranchProgramArgs{
-			BranchInfos:   data.branchInfos,
-			Config:        data.config.Config,
-			InitialBranch: data.initialBranch,
-			Program:       prog,
-			PushBranches:  true,
-			Remotes:       data.remotes,
+			BranchInfos:         data.branchInfos,
+			Config:              data.config,
+			InitialBranch:       data.initialBranch,
+			PrefetchBranchInfos: data.preFetchBranchInfos,
+			Program:             prog,
+			PushBranches:        true,
+			Remotes:             data.remotes,
 		})
 	}
-	prog.Value.Add(&opcodes.CreateAndCheckoutBranchExistingParent{
+	prog.Value.Add(&opcodes.BranchCreateAndCheckoutExistingParent{
 		Ancestors: data.newParentCandidates,
 		Branch:    data.targetBranch,
 	})
 	// set the parent of the newly created branch
-	prog.Value.Add(&opcodes.SetExistingParent{
+	prog.Value.Add(&opcodes.LineageParentSetFirstExisting{
 		Branch:    data.targetBranch,
 		Ancestors: data.newParentCandidates,
 	})
 	// set the parent of the branch prepended to
-	prog.Value.Add(&opcodes.SetParentIfBranchExists{
+	prog.Value.Add(&opcodes.LineageParentSetIfExists{
 		Branch: data.initialBranch,
 		Parent: data.targetBranch,
 	})
-	if data.prototype.IsTrue() || data.config.Config.CreatePrototypeBranches.IsTrue() {
-		prog.Value.Add(&opcodes.AddToPrototypeBranches{Branch: data.targetBranch})
+	if data.prototype.IsTrue() || data.config.NormalConfig.CreatePrototypeBranches.IsTrue() {
+		prog.Value.Add(&opcodes.BranchesPrototypeAdd{Branch: data.targetBranch})
 	}
 	proposal, hasProposal := data.proposal.Get()
-	if data.remotes.HasOrigin() && data.config.Config.IsOnline() && (data.config.Config.ShouldPushNewBranches() || hasProposal) {
-		prog.Value.Add(&opcodes.CreateTrackingBranch{Branch: data.targetBranch})
+	if data.remotes.HasOrigin() && data.config.NormalConfig.IsOnline() && (data.config.NormalConfig.ShouldPushNewBranches() || hasProposal) {
+		prog.Value.Add(&opcodes.BranchTrackingCreate{Branch: data.targetBranch})
 	}
-	if hasProposal {
-		prog.Value.Add(&opcodes.UpdateProposalBase{
-			NewTarget:      data.targetBranch,
-			OldTarget:      data.existingParent,
+	connector, hasConnector := data.connector.Get()
+	connectorCanUpdateProposalTargets := hasConnector && connector.UpdateProposalTargetFn().IsSome()
+	if hasProposal && hasConnector && connectorCanUpdateProposalTargets {
+		prog.Value.Add(&opcodes.ProposalUpdateTarget{
+			NewBranch:      data.targetBranch,
+			OldBranch:      data.existingParent,
 			ProposalNumber: proposal.Number,
 		})
 	}
