@@ -32,7 +32,7 @@ Merges the given or current feature branch into its parent.
 How exactly this happen depends on the configured ship-strategy.
 
 Ships only direct children of the main branch.
-To ship a child branch, ship or kill all ancestor branches first
+To ship a child branch, ship or delete all ancestor branches first
 or ship with the "--to-parent" flag.
 
 To use the online functionality, configure a personal access token with the "repo" scope
@@ -82,26 +82,29 @@ func executeShip(args []string, message Option[gitdomain.CommitMessage], dryRun
 	if err != nil {
 		return err
 	}
-	var shipProgram program.Program
-	switch sharedData.config.Config.ShipStrategy {
+	prog := NewMutable(&program.Program{})
+	switch sharedData.config.NormalConfig.ShipStrategy {
 	case configdomain.ShipStrategyAPI:
 		apiData, err := determineAPIData(sharedData)
 		if err != nil {
 			return err
 		}
-		shipProgram = shipAPIProgram(sharedData, apiData, message)
+		err = shipAPIProgram(prog, sharedData, apiData, message)
+		if err != nil {
+			return err
+		}
 	case configdomain.ShipStragegyFastForward:
-		mergeData, err := determineMergeData(repo)
+		mergeData, err := determineMergeData(repo, sharedData.branchNameToShip, sharedData.targetBranchName)
 		if err != nil {
 			return err
 		}
-		shipProgram = shipProgramFastForward(sharedData, mergeData)
+		shipProgramFastForward(prog, sharedData, mergeData)
 	case configdomain.ShipStrategySquashMerge:
-		squashMergeData, err := determineMergeData(repo)
+		squashMergeData, err := determineMergeData(repo, sharedData.branchNameToShip, sharedData.targetBranchName)
 		if err != nil {
 			return err
 		}
-		shipProgram = shipProgramSquashMerge(sharedData, squashMergeData, message)
+		shipProgramSquashMerge(prog, sharedData, squashMergeData, message)
 	}
 	runState := runstate.RunState{
 		BeginBranchesSnapshot: sharedData.branchesSnapshot,
@@ -112,8 +115,8 @@ func executeShip(args []string, message Option[gitdomain.CommitMessage], dryRun
 		EndBranchesSnapshot:   None[gitdomain.BranchesSnapshot](),
 		EndConfigSnapshot:     None[undoconfig.ConfigSnapshot](),
 		EndStashSize:          None[gitdomain.StashSize](),
-		RunProgram:            shipProgram,
-		TouchedBranches:       shipProgram.TouchedBranches(),
+		RunProgram:            prog.Get(),
+		TouchedBranches:       prog.Value.TouchedBranches(),
 		UndoAPIProgram:        program.Program{},
 	}
 	return fullInterpreter.Execute(fullInterpreter.ExecuteArgs{
@@ -136,25 +139,25 @@ func executeShip(args []string, message Option[gitdomain.CommitMessage], dryRun
 	})
 }
 
-func UpdateChildBranchProposals(prog *program.Program, proposals []hostingdomain.Proposal, targetBranch gitdomain.LocalBranchName) {
+func UpdateChildBranchProposalsToGrandParent(prog *program.Program, proposals []hostingdomain.Proposal) {
 	for _, childProposal := range proposals {
-		prog.Add(&opcodes.UpdateProposalBase{
-			ProposalNumber: childProposal.Number,
-			NewTarget:      targetBranch,
+		prog.Add(&opcodes.ProposalUpdateTargetToParent{
+			Branch:         childProposal.Source,
 			OldTarget:      childProposal.Target,
+			ProposalNumber: childProposal.Number,
 		})
 	}
 }
 
 func validateSharedData(data sharedShipData, toParent configdomain.ShipIntoNonperennialParent, message Option[gitdomain.CommitMessage]) error {
-	if data.config.Config.ShipStrategy == configdomain.ShipStragegyFastForward && message.IsSome() {
+	if data.config.NormalConfig.ShipStrategy == configdomain.ShipStragegyFastForward && message.IsSome() {
 		return errors.New(messages.ShipMessageWithFastForward)
 	}
 	if !toParent {
 		branch := data.branchToShip.LocalName.GetOrPanic()
 		parentBranch := data.targetBranch.LocalName.GetOrPanic()
-		if !data.config.Config.IsMainOrPerennialBranch(parentBranch) {
-			ancestors := data.config.Config.Lineage.Ancestors(branch)
+		if !data.config.IsMainOrPerennialBranch(parentBranch) {
+			ancestors := data.config.NormalConfig.Lineage.Ancestors(branch)
 			ancestorsWithoutMainOrPerennial := ancestors[1:]
 			oldestAncestor := ancestorsWithoutMainOrPerennial[0]
 			return fmt.Errorf(messages.ShipChildBranch, stringslice.Connect(ancestorsWithoutMainOrPerennial.Strings()), oldestAncestor)
@@ -162,12 +165,18 @@ func validateSharedData(data sharedShipData, toParent configdomain.ShipIntoNonpe
 	}
 	switch data.branchToShip.SyncStatus {
 	case gitdomain.SyncStatusDeletedAtRemote:
-		return fmt.Errorf(messages.ShipBranchDeletedAtRemote, data.branchNameToShip)
-	case gitdomain.SyncStatusNotInSync:
+		return fmt.Errorf(messages.BranchDeletedAtRemote, data.branchNameToShip)
+	case
+		gitdomain.SyncStatusNotInSync,
+		gitdomain.SyncStatusAhead,
+		gitdomain.SyncStatusBehind:
 		return fmt.Errorf(messages.ShipBranchNotInSync, data.branchNameToShip)
 	case gitdomain.SyncStatusOtherWorktree:
 		return fmt.Errorf(messages.ShipBranchIsInOtherWorktree, data.branchNameToShip)
-	case gitdomain.SyncStatusUpToDate, gitdomain.SyncStatusRemoteOnly, gitdomain.SyncStatusLocalOnly:
+	case
+		gitdomain.SyncStatusUpToDate,
+		gitdomain.SyncStatusRemoteOnly,
+		gitdomain.SyncStatusLocalOnly:
 	}
 	if localName, hasLocalName := data.branchToShip.LocalName.Get(); hasLocalName {
 		if localName == data.initialBranch {
