@@ -80,7 +80,7 @@ func determineSharedShipData(args []string, repo execute.OpenRepoResult, dryRun
 		return data, false, fmt.Errorf(messages.BranchDoesntExist, branchNameToShip)
 	}
 	localBranches := branchesSnapshot.Branches.LocalBranches().Names()
-	branchesAndTypes := repo.UnvalidatedConfig.Config.Value.BranchesAndTypes(branchesSnapshot.Branches.LocalBranches().Names())
+	branchesAndTypes := repo.UnvalidatedConfig.UnvalidatedBranchesAndTypes(branchesSnapshot.Branches.LocalBranches().Names())
 	validatedConfig, exit, err := validate.Config(validate.ConfigArgs{
 		Backend:            repo.Backend,
 		BranchesAndTypes:   branchesAndTypes,
@@ -93,12 +93,12 @@ func determineSharedShipData(args []string, repo execute.OpenRepoResult, dryRun
 		LocalBranches:      localBranches,
 		RepoStatus:         repoStatus,
 		TestInputs:         dialogTestInputs,
-		Unvalidated:        repo.UnvalidatedConfig,
+		Unvalidated:        NewMutable(&repo.UnvalidatedConfig),
 	})
 	if err != nil || exit {
 		return data, exit, err
 	}
-	switch validatedConfig.Config.BranchType(branchNameToShip) {
+	switch validatedConfig.BranchType(branchNameToShip) {
 	case configdomain.BranchTypeContributionBranch:
 		return data, false, errors.New(messages.ContributionBranchCannotShip)
 	case configdomain.BranchTypeMainBranch:
@@ -107,9 +107,12 @@ func determineSharedShipData(args []string, repo execute.OpenRepoResult, dryRun
 		return data, false, errors.New(messages.ObservedBranchCannotShip)
 	case configdomain.BranchTypePerennialBranch:
 		return data, false, errors.New(messages.PerennialBranchCannotShip)
-	case configdomain.BranchTypeFeatureBranch, configdomain.BranchTypeParkedBranch, configdomain.BranchTypePrototypeBranch:
+	case
+		configdomain.BranchTypeFeatureBranch,
+		configdomain.BranchTypeParkedBranch,
+		configdomain.BranchTypePrototypeBranch:
 	}
-	targetBranchName, hasTargetBranch := validatedConfig.Config.Lineage.Parent(branchNameToShip).Get()
+	targetBranchName, hasTargetBranch := validatedConfig.NormalConfig.Lineage.Parent(branchNameToShip).Get()
 	if !hasTargetBranch {
 		return data, false, fmt.Errorf(messages.ShipBranchHasNoParent, branchNameToShip)
 	}
@@ -117,14 +120,14 @@ func determineSharedShipData(args []string, repo execute.OpenRepoResult, dryRun
 	if !hasTargetBranch {
 		return data, false, fmt.Errorf(messages.BranchDoesntExist, targetBranchName)
 	}
-	childBranches := validatedConfig.Config.Lineage.Children(branchNameToShip)
+	childBranches := validatedConfig.NormalConfig.Lineage.Children(branchNameToShip)
 	connectorOpt, err := hosting.NewConnector(repo.UnvalidatedConfig, gitdomain.RemoteOrigin, print.Logger{})
 	if err != nil {
 		return data, false, err
 	}
 	proposalsOfChildBranches := LoadProposalsOfChildBranches(LoadProposalsOfChildBranchesArgs{
 		ConnectorOpt:               connectorOpt,
-		Lineage:                    validatedConfig.Config.Lineage,
+		Lineage:                    validatedConfig.NormalConfig.Lineage,
 		Offline:                    repo.IsOffline,
 		OldBranch:                  branchNameToShip,
 		OldBranchHasTrackingBranch: branchToShip.HasTrackingBranch(),
@@ -150,24 +153,35 @@ func determineSharedShipData(args []string, repo execute.OpenRepoResult, dryRun
 }
 
 func LoadProposalsOfChildBranches(args LoadProposalsOfChildBranchesArgs) []hostingdomain.Proposal {
-	var proposalsOfChildBranches []hostingdomain.Proposal
-	childBranches := args.Lineage.Children(args.OldBranch)
 	connector, hasConnector := args.ConnectorOpt.Get()
-	if hasConnector && connector.CanMakeAPICalls() {
-		if !args.Offline.IsTrue() && args.OldBranchHasTrackingBranch {
-			for _, childBranch := range childBranches {
-				childProposalOpt, err := connector.FindProposal(childBranch, args.OldBranch)
-				if err != nil {
-					continue
-				}
-				childProposal, hasChildProposal := childProposalOpt.Get()
-				if hasChildProposal {
-					proposalsOfChildBranches = append(proposalsOfChildBranches, childProposal)
-				}
-			}
-		}
+	if !hasConnector {
+		return []hostingdomain.Proposal{}
 	}
-	return proposalsOfChildBranches
+	findProposal, canFindProposal := connector.FindProposalFn().Get()
+	if !canFindProposal {
+		return []hostingdomain.Proposal{}
+	}
+	if args.Offline.IsTrue() {
+		return []hostingdomain.Proposal{}
+	}
+	if !args.OldBranchHasTrackingBranch {
+		return []hostingdomain.Proposal{}
+	}
+	childBranches := args.Lineage.Children(args.OldBranch)
+	result := make([]hostingdomain.Proposal, 0, len(childBranches))
+	for _, childBranch := range childBranches {
+		childProposalOpt, err := findProposal(childBranch, args.OldBranch)
+		if err != nil {
+			print.Error(err)
+			continue
+		}
+		childProposal, hasChildProposal := childProposalOpt.Get()
+		if !hasChildProposal {
+			continue
+		}
+		result = append(result, childProposal)
+	}
+	return result
 }
 
 type LoadProposalsOfChildBranchesArgs struct {
@@ -180,12 +194,21 @@ type LoadProposalsOfChildBranchesArgs struct {
 
 func FindProposal(connectorOpt Option[hostingdomain.Connector], sourceBranch gitdomain.LocalBranchName, targetBranch Option[gitdomain.LocalBranchName]) Option[hostingdomain.Proposal] {
 	connector, hasConnector := connectorOpt.Get()
-	target, hasTarget := targetBranch.Get()
-	if hasConnector && connector.CanMakeAPICalls() && hasTarget {
-		proposalOpt, err := connector.FindProposal(sourceBranch, target)
-		if err == nil {
-			return proposalOpt
-		}
+	if !hasConnector {
+		return None[hostingdomain.Proposal]()
 	}
-	return None[hostingdomain.Proposal]()
+	target, hasTarget := targetBranch.Get()
+	if !hasTarget {
+		return None[hostingdomain.Proposal]()
+	}
+	findProposal, canFindProposal := connector.FindProposalFn().Get()
+	if !canFindProposal {
+		return None[hostingdomain.Proposal]()
+	}
+	proposal, err := findProposal(sourceBranch, target)
+	if err != nil {
+		print.Error(err)
+		return None[hostingdomain.Proposal]()
+	}
+	return proposal
 }
