@@ -10,50 +10,55 @@ import (
 )
 
 type shipDataMerge struct {
+	authors []gitdomain.Author
 	remotes gitdomain.Remotes
 }
 
-func determineMergeData(repo execute.OpenRepoResult) (result shipDataMerge, err error) {
+func determineMergeData(repo execute.OpenRepoResult, branch, parent gitdomain.LocalBranchName) (result shipDataMerge, err error) {
 	remotes, err := repo.Git.Remotes(repo.Backend)
 	if err != nil {
 		return result, err
 	}
+	branchAuthors, err := repo.Git.BranchAuthors(repo.Backend, branch, parent)
+	if err != nil {
+		return result, err
+	}
 	return shipDataMerge{
+		authors: branchAuthors,
 		remotes: remotes,
 	}, nil
 }
 
-func shipProgramSquashMerge(sharedData sharedShipData, squashMergeData shipDataMerge, commitMessage Option[gitdomain.CommitMessage]) program.Program {
-	prog := NewMutable(&program.Program{})
-	prog.Value.Add(&opcodes.EnsureHasShippableChanges{Branch: sharedData.branchNameToShip, Parent: sharedData.targetBranchName})
+func shipProgramSquashMerge(prog Mutable[program.Program], sharedData sharedShipData, squashMergeData shipDataMerge, commitMessage Option[gitdomain.CommitMessage]) {
+	prog.Value.Add(&opcodes.BranchEnsureShippableChanges{Branch: sharedData.branchNameToShip, Parent: sharedData.targetBranchName})
 	localTargetBranch, _ := sharedData.targetBranch.LocalName.Get()
 	if sharedData.initialBranch != sharedData.targetBranchName {
 		prog.Value.Add(&opcodes.CheckoutIfNeeded{Branch: sharedData.targetBranchName})
 	}
-	if squashMergeData.remotes.HasOrigin() && sharedData.config.Config.IsOnline() {
-		UpdateChildBranchProposals(prog.Value, sharedData.proposalsOfChildBranches, localTargetBranch)
+	if squashMergeData.remotes.HasOrigin() && sharedData.config.NormalConfig.IsOnline() {
+		UpdateChildBranchProposalsToGrandParent(prog.Value, sharedData.proposalsOfChildBranches)
 	}
-	prog.Value.Add(&opcodes.SquashMerge{Branch: sharedData.branchNameToShip, CommitMessage: commitMessage, Parent: localTargetBranch})
-	if squashMergeData.remotes.HasOrigin() && sharedData.config.Config.IsOnline() {
+	prog.Value.Add(&opcodes.MergeSquashProgram{Authors: squashMergeData.authors, Branch: sharedData.branchNameToShip, CommitMessage: commitMessage, Parent: localTargetBranch})
+	if squashMergeData.remotes.HasOrigin() && sharedData.config.NormalConfig.IsOnline() {
 		prog.Value.Add(&opcodes.PushCurrentBranchIfNeeded{CurrentBranch: sharedData.targetBranchName})
 	}
 	if !sharedData.dryRun {
-		prog.Value.Add(&opcodes.DeleteParentBranch{Branch: sharedData.branchNameToShip})
+		prog.Value.Add(&opcodes.BranchParentDelete{Branch: sharedData.branchNameToShip})
 	}
 	if branchToShipRemoteName, hasRemoteName := sharedData.branchToShip.RemoteName.Get(); hasRemoteName {
-		if sharedData.config.Config.IsOnline() {
-			if sharedData.config.Config.ShipDeleteTrackingBranch {
-				prog.Value.Add(&opcodes.DeleteTrackingBranch{Branch: branchToShipRemoteName})
+		if sharedData.config.NormalConfig.IsOnline() {
+			if sharedData.config.NormalConfig.ShipDeleteTrackingBranch {
+				prog.Value.Add(&opcodes.BranchTrackingDelete{Branch: branchToShipRemoteName})
 			}
 		}
 	}
 	for _, child := range sharedData.childBranches {
-		prog.Value.Add(&opcodes.ChangeParent{Branch: child, Parent: localTargetBranch})
+		prog.Value.Add(&opcodes.LineageParentSetToGrandParent{Branch: child})
 	}
 	if !sharedData.isShippingInitialBranch {
 		prog.Value.Add(&opcodes.CheckoutIfNeeded{Branch: sharedData.initialBranch})
 	}
-	prog.Value.Add(&opcodes.DeleteLocalBranch{Branch: sharedData.branchNameToShip})
+	prog.Value.Add(&opcodes.BranchLocalDelete{Branch: sharedData.branchNameToShip})
 	previousBranchCandidates := []Option[gitdomain.LocalBranchName]{sharedData.previousBranch}
 	cmdhelpers.Wrap(prog, cmdhelpers.WrapOptions{
 		DryRun:                   sharedData.dryRun,
@@ -61,5 +66,4 @@ func shipProgramSquashMerge(sharedData sharedShipData, squashMergeData shipDataM
 		StashOpenChanges:         !sharedData.isShippingInitialBranch && sharedData.hasOpenChanges,
 		PreviousBranchCandidates: previousBranchCandidates,
 	})
-	return prog.Get()
 }
