@@ -31,12 +31,12 @@ func AllAliasableCommands() AliasableCommands {
 		AliasableCommandContribute,
 		AliasableCommandDiffParent,
 		AliasableCommandHack,
-		AliasableCommandKill,
+		AliasableCommandDelete,
 		AliasableCommandObserve,
 		AliasableCommandPark,
 		AliasableCommandPrepend,
 		AliasableCommandPropose,
-		AliasableCommandRenameBranch,
+		AliasableCommandRename,
 		AliasableCommandRepo,
 		AliasableCommandSetParent,
 		AliasableCommandShip,
