@@ -11,6 +11,18 @@ import (
 // Key contains all the keys used in Git Town's Git metadata configuration.
 type Key string
 
+// ConfigSetting contains a key-value pair for a configuration setting.
+type ConfigSetting struct {
+	Key   Key
+	Value string
+}
+
+// ConfigUpdate contains the before and after values of a configuration setting.
+type ConfigUpdate struct {
+	After  ConfigSetting
+	Before ConfigSetting
+}
+
 // MarshalJSON is used when serializing this LocalBranchName to JSON.
 func (self Key) MarshalJSON() ([]byte, error) {
 	return json.Marshal(self.String())
@@ -32,12 +44,12 @@ const (
 	KeyAliasContribute                     = Key("alias.contribute")
 	KeyAliasDiffParent                     = Key("alias.diff-parent")
 	KeyAliasHack                           = Key("alias.hack")
-	KeyAliasKill                           = Key("alias.kill")
+	KeyAliasDelete                         = Key("alias.delete")
 	KeyAliasObserve                        = Key("alias.observe")
 	KeyAliasPark                           = Key("alias.park")
 	KeyAliasPrepend                        = Key("alias.prepend")
 	KeyAliasPropose                        = Key("alias.propose")
-	KeyAliasRenameBranch                   = Key("alias.rename-branch")
+	KeyAliasRename                         = Key("alias.rename")
 	KeyAliasRepo                           = Key("alias.repo")
 	KeyAliasSetParent                      = Key("alias.set-parent")
 	KeyAliasShip                           = Key("alias.ship")
@@ -51,6 +63,8 @@ const (
 	KeyDeprecatedCodeHostingDriver         = Key("git-town.code-hosting-driver")
 	KeyDeprecatedCodeHostingOriginHostname = Key("git-town.code-hosting-origin-hostname")
 	KeyDeprecatedCodeHostingPlatform       = Key("git-town.code-hosting-platform")
+	KeyDeprecatedAliasKill                 = Key("alias.kill")
+	KeyDeprecatedAliasRenameBranch         = Key("alias.rename-branch")
 	KeyDeprecatedMainBranchName            = Key("git-town.main-branch-name")
 	KeyDeprecatedNewBranchPushFlag         = Key("git-town.new-branch-push-flag")
 	KeyDeprecatedPerennialBranchNames      = Key("git-town.perennial-branch-names")
@@ -96,6 +110,8 @@ var keys = []Key{ //nolint:gochecknoglobals
 	KeyContributionRegex,
 	KeyCreatePrototypeBranches,
 	KeyDefaultBranchType,
+	KeyDeprecatedAliasKill,
+	KeyDeprecatedAliasRenameBranch,
 	KeyDeprecatedCodeHostingDriver,
 	KeyDeprecatedCodeHostingOriginHostname,
 	KeyDeprecatedCodeHostingPlatform,
@@ -170,3 +186,27 @@ var DeprecatedKeys = map[Key]Key{ //nolint:gochecknoglobals
 var ObsoleteKeys = []Key{ //nolint:gochecknoglobals
 	KeyObsoleteSyncBeforeShip,
 }
+
+// ConfigUpdates defines the config that should have its keys and values to be updated
+var ConfigUpdates = []ConfigUpdate{ //nolint:gochecknoglobals
+	{
+		Before: ConfigSetting{
+			Key:   KeyDeprecatedAliasKill,
+			Value: "town kill",
+		},
+		After: ConfigSetting{
+			Key:   KeyAliasDelete,
+			Value: "town delete",
+		},
+	},
+	{
+		Before: ConfigSetting{
+			Key:   KeyDeprecatedAliasRenameBranch,
+			Value: "town rename-branch",
+		},
+		After: ConfigSetting{
+			Key:   KeyAliasRename,
+			Value: "town rename",
+		},
+	},
+}
