@@ -1,6 +1,7 @@
 package config_test
 
 import (
+	"fmt"
 	"os"
 	"testing"
 
@@ -16,17 +17,35 @@ import (
 func TestValidatedConfig(t *testing.T) {
 	t.Parallel()
 
-	t.Run("Author", func(t *testing.T) {
+	t.Run("IsMainOrPerennialBranch", func(t *testing.T) {
 		t.Parallel()
-		conf := config.ValidatedConfig{
-			Config: configdomain.ValidatedConfig{
-				GitUserName:  configdomain.GitUserName("name"),
-				GitUserEmail: configdomain.GitUserEmail("email"),
+		config := config.ValidatedConfig{
+			ValidatedConfigData: configdomain.ValidatedConfigData{
+				MainBranch: "main",
+			},
+			NormalConfig: config.NormalConfig{
+				NormalConfigData: configdomain.NormalConfigData{
+					ContributionBranches: gitdomain.NewLocalBranchNames("contribution"),
+					PerennialBranches:    gitdomain.NewLocalBranchNames("perennial-1", "perennial-2"),
+					ObservedBranches:     gitdomain.NewLocalBranchNames("observed"),
+					ParkedBranches:       gitdomain.NewLocalBranchNames("parked"),
+				},
 			},
 		}
-		have := conf.Author()
-		want := gitdomain.Author("name <email>")
-		must.EqOp(t, want, have)
+		tests := map[string]bool{
+			"feature":     false,
+			"main":        true,
+			"perennial-1": true,
+			"perennial-2": true,
+			"perennial-3": false,
+			"observed":    false,
+			"parked":      false,
+		}
+		for give, want := range tests {
+			have := config.IsMainOrPerennialBranch(gitdomain.NewLocalBranchName(give))
+			fmt.Println(give)
+			must.Eq(t, want, have)
+		}
 	})
 
 	t.Run("Lineage", func(t *testing.T) {
@@ -35,13 +54,30 @@ func TestValidatedConfig(t *testing.T) {
 		repo.CreateFeatureBranch("feature1", "main")
 		repo.CreateFeatureBranch("feature2", "main")
 		repo.Config.Reload()
-		have := repo.Config.Config.Lineage
+		have := repo.Config.NormalConfig.Lineage
 		want := configdomain.NewLineage()
 		want.Add(gitdomain.NewLocalBranchName("feature1"), gitdomain.NewLocalBranchName("main"))
 		want.Add(gitdomain.NewLocalBranchName("feature2"), gitdomain.NewLocalBranchName("main"))
 		must.Eq(t, want, have)
 	})
 
+	t.Run("MainAndPerennials", func(t *testing.T) {
+		t.Parallel()
+		config := config.ValidatedConfig{
+			ValidatedConfigData: configdomain.ValidatedConfigData{
+				MainBranch: "main",
+			},
+			NormalConfig: config.NormalConfig{
+				NormalConfigData: configdomain.NormalConfigData{
+					PerennialBranches: gitdomain.NewLocalBranchNames("perennial-1", "perennial-2"),
+				},
+			},
+		}
+		have := config.MainAndPerennials()
+		want := gitdomain.NewLocalBranchNames("main", "perennial-1", "perennial-2")
+		must.Eq(t, want, have)
+	})
+
 	t.Run("RemoteURL", func(t *testing.T) {
 		t.Parallel()
 		tests := map[string]giturl.Parts{
@@ -56,26 +92,12 @@ func TestValidatedConfig(t *testing.T) {
 			repo := testruntime.CreateGitTown(t)
 			os.Setenv("GIT_TOWN_REMOTE", give)
 			defer os.Unsetenv("GIT_TOWN_REMOTE")
-			have, has := repo.Config.RemoteURL(gitdomain.RemoteOrigin).Get()
+			have, has := repo.Config.NormalConfig.RemoteURL(gitdomain.RemoteOrigin).Get()
 			must.True(t, has)
 			must.EqOp(t, want, have)
 		}
 	})
 
-	t.Run("Reload", func(t *testing.T) {
-		t.Parallel()
-		t.Run("lineage changed", func(t *testing.T) {
-			t.Parallel()
-			repo := testruntime.CreateGitTown(t)
-			branch := gitdomain.NewLocalBranchName("branch-1")
-			repo.CreateFeatureBranch(branch, "main")
-			repo.Config.Reload()
-			want := configdomain.NewLineage()
-			want.Add(branch, gitdomain.NewLocalBranchName("main"))
-			must.Eq(t, want, repo.Config.Config.Lineage)
-		})
-	})
-
 	t.Run("RemovePerennialRoot", func(t *testing.T) {
 		t.Parallel()
 		contribution := gitdomain.NewLocalBranchName("contribution")
@@ -89,15 +111,19 @@ func TestValidatedConfig(t *testing.T) {
 		prototype := gitdomain.NewLocalBranchName("prototype")
 		perennialRegexOpt, err := configdomain.ParsePerennialRegex("peren*")
 		must.NoError(t, err)
-		config := configdomain.ValidatedConfig{
-			MainBranch: gitdomain.NewLocalBranchName("main"),
-			UnvalidatedConfig: &configdomain.UnvalidatedConfig{
-				ContributionBranches: gitdomain.LocalBranchNames{contribution},
-				ObservedBranches:     gitdomain.LocalBranchNames{observed},
-				ParkedBranches:       gitdomain.LocalBranchNames{parked},
-				PerennialBranches:    gitdomain.LocalBranchNames{perennial1},
-				PerennialRegex:       perennialRegexOpt,
-				PrototypeBranches:    gitdomain.LocalBranchNames{prototype},
+		config := config.ValidatedConfig{
+			ValidatedConfigData: configdomain.ValidatedConfigData{
+				MainBranch: "main",
+			},
+			NormalConfig: config.NormalConfig{
+				NormalConfigData: configdomain.NormalConfigData{
+					ContributionBranches: gitdomain.LocalBranchNames{contribution},
+					ObservedBranches:     gitdomain.LocalBranchNames{observed},
+					ParkedBranches:       gitdomain.LocalBranchNames{parked},
+					PerennialBranches:    gitdomain.LocalBranchNames{perennial1},
+					PerennialRegex:       perennialRegexOpt,
+					PrototypeBranches:    gitdomain.LocalBranchNames{prototype},
+				},
 			},
 		}
 		tests := map[*gitdomain.LocalBranchNames]gitdomain.LocalBranchNames{
