@@ -3,6 +3,7 @@ package execute
 import (
 	"errors"
 
+	"github.com/git-town/git-town/v16/internal/config"
 	"github.com/git-town/git-town/v16/internal/config/configdomain"
 	"github.com/git-town/git-town/v16/internal/git/gitdomain"
 	"github.com/git-town/git-town/v16/internal/messages"
@@ -10,7 +11,7 @@ import (
 )
 
 // provides the branches to make contribution, observed, parked, or prototype
-func BranchesToMark(args []string, branchesSnapshot gitdomain.BranchesSnapshot, config configdomain.UnvalidatedConfig) (branchesToMark configdomain.BranchesAndTypes, branchToCheckout Option[gitdomain.LocalBranchName], err error) {
+func BranchesToMark(args []string, branchesSnapshot gitdomain.BranchesSnapshot, config config.UnvalidatedConfig) (branchesToMark configdomain.BranchesAndTypes, branchToCheckout Option[gitdomain.LocalBranchName], err error) {
 	branchesToMark = configdomain.BranchesAndTypes{}
 	switch len(args) {
 	case 0:
@@ -18,11 +19,11 @@ func BranchesToMark(args []string, branchesSnapshot gitdomain.BranchesSnapshot,
 		if !hasCurrentBranch {
 			return branchesToMark, branchToCheckout, errors.New(messages.CurrentBranchCannotDetermine)
 		}
-		branchesToMark.Add(currentBranch, config)
+		branchesToMark.Add(currentBranch, &config)
 		branchToCheckout = None[gitdomain.LocalBranchName]()
 	case 1:
 		branch := gitdomain.NewLocalBranchName(args[0])
-		branchesToMark.Add(branch, config)
+		branchesToMark.Add(branch, &config)
 		branchInfo, hasBranchInfo := branchesSnapshot.Branches.FindByRemoteName(branch.TrackingBranch()).Get()
 		if hasBranchInfo && branchInfo.SyncStatus == gitdomain.SyncStatusRemoteOnly {
 			branchToCheckout = Some(branch)
@@ -30,7 +31,7 @@ func BranchesToMark(args []string, branchesSnapshot gitdomain.BranchesSnapshot,
 			branchToCheckout = None[gitdomain.LocalBranchName]()
 		}
 	default:
-		branchesToMark.AddMany(gitdomain.NewLocalBranchNames(args...), config)
+		branchesToMark.AddMany(gitdomain.NewLocalBranchNames(args...), &config)
 		branchToCheckout = None[gitdomain.LocalBranchName]()
 	}
 	return branchesToMark, branchToCheckout, nil
