@@ -39,7 +39,7 @@ func (self *Commands) AbortRebase(runner gitdomain.Runner) error {
 func (self *Commands) BranchAuthors(querier gitdomain.Querier, branch, parent gitdomain.LocalBranchName) ([]gitdomain.Author, error) {
 	output, err := querier.QueryTrim("git", "shortlog", "-s", "-n", "-e", parent.String()+".."+branch.String())
 	if err != nil {
-		return []gitdomain.Author(nil), err
+		return []gitdomain.Author{}, err
 	}
 	lines := stringslice.Lines(output)
 	result := make([]gitdomain.Author, len(lines))
@@ -110,6 +110,10 @@ func (self *Commands) CheckoutBranchUncached(runner gitdomain.Runner, name gitdo
 	return nil
 }
 
+func (self *Commands) CheckoutOurVersion(runner gitdomain.Runner, file string) error {
+	return runner.Run("git", "checkout", "--ours", file)
+}
+
 // CommentOutSquashCommitMessage comments out the message for the current squash merge
 // Adds the given prefix with the newline if provided.
 func (self *Commands) CommentOutSquashCommitMessage(prefix string) error {
@@ -194,6 +198,16 @@ func (self *Commands) CommitsInPerennialBranch(querier gitdomain.Querier) (gitdo
 	return result, nil
 }
 
+// provides the SHA1 checksum of the content blob of the given file on the given branch/sha
+func (self *Commands) ContentBlobInfo(querier gitdomain.Querier, branch gitdomain.Location, filePath string) (Option[BlobInfo], error) {
+	output, err := querier.QueryTrim("git", "ls-tree", branch.String(), filePath)
+	if err != nil || len(output) == 0 {
+		return None[BlobInfo](), err
+	}
+	sha, err := ParseLsTreeOutput(output)
+	return Some(sha), err
+}
+
 // ContinueRebase continues the currently ongoing rebase.
 func (self *Commands) ContinueRebase(runner gitdomain.Runner) error {
 	return runner.Run("git", "rebase", "--continue")
@@ -261,6 +275,12 @@ func (self *Commands) CurrentBranch(querier gitdomain.Querier) (gitdomain.LocalB
 	return self.CurrentBranchCache.Value(), nil
 }
 
+// indicates whether the currently checked out branch has a tracking branch or not
+func (self *Commands) CurrentBranchHasTrackingBranch(runner gitdomain.Runner) bool {
+	err := runner.Run("git", "rev-parse", "--abbrev-ref", "--symbolic-full-name", "@{u}")
+	return err == nil
+}
+
 // CurrentBranch provides the currently checked out branch.
 func (self *Commands) CurrentBranchUncached(querier gitdomain.Querier) (gitdomain.LocalBranchName, error) {
 	// first try to detect the current branch the normal way
@@ -343,22 +363,58 @@ func (self *Commands) FetchUpstream(runner gitdomain.Runner, branch gitdomain.Lo
 	return runner.Run("git", "fetch", gitdomain.RemoteUpstream.String(), branch.String())
 }
 
+// provides enough information about the unresolved merge conflict for the given file to determine whether this is a phantom merge conflict
+func (self *Commands) FileConflictFullInfo(querier gitdomain.Querier, quickInfo FileConflictQuickInfo, parentLocation gitdomain.Location, mainBranch gitdomain.LocalBranchName) (FileConflictFullInfo, error) {
+	mainBlob, err := self.ContentBlobInfo(querier, mainBranch.Location(), quickInfo.CurrentBranchChange.FilePath)
+	if err != nil {
+		return FileConflictFullInfo{}, err
+	}
+	// this is the blob at the original parent, before Git Town ran
+	parentBlob, err := self.ContentBlobInfo(querier, parentLocation, quickInfo.CurrentBranchChange.FilePath)
+	if err != nil {
+		return FileConflictFullInfo{}, err
+	}
+	result := FileConflictFullInfo{
+		Current: quickInfo.CurrentBranchChange,
+		Main:    mainBlob,
+		Parent:  parentBlob,
+	}
+	return result, nil
+}
+
+// provides enough information about the unresolved merge conflicts for the given files to determine the phantom merge conflicts among them
+func (self *Commands) FileConflictFullInfos(querier gitdomain.Querier, quickInfos []FileConflictQuickInfo, parentLocation gitdomain.Location, mainBranch gitdomain.LocalBranchName) ([]FileConflictFullInfo, error) {
+	result := make([]FileConflictFullInfo, len(quickInfos))
+	for q, quickInfo := range quickInfos {
+		fullInfo, err := self.FileConflictFullInfo(querier, quickInfo, parentLocation, mainBranch)
+		if err != nil {
+			return result, err
+		}
+		result[q] = fullInfo
+	}
+	return result, nil
+}
+
+// provides information about files with merge conflicts during a merge conflict
+func (self *Commands) FileConflictQuickInfos(querier gitdomain.Querier) ([]FileConflictQuickInfo, error) {
+	output, err := querier.Query("git", "ls-files", "--unmerged")
+	if err != nil {
+		return []FileConflictQuickInfo{}, err
+	}
+	return ParseLsFilesUnmergedOutput(output)
+}
+
 // provides the commit message of the first commit in the branch with the given name
-func (self *Commands) FirstCommitMessageInBranch(runner gitdomain.Querier, branch, mainBranch gitdomain.BranchName) (Option[gitdomain.CommitMessage], error) {
-	output, err := runner.QueryTrim("git", "log", fmt.Sprintf("%s..%s", mainBranch, branch), "--format=%h")
+func (self *Commands) FirstCommitMessageInBranch(runner gitdomain.Querier, branch, parent gitdomain.BranchName) (Option[gitdomain.CommitMessage], error) {
+	output, err := runner.QueryTrim("git", "log", fmt.Sprintf("%s..%s", parent, branch), "--format=%s", "--reverse")
 	if err != nil {
 		return None[gitdomain.CommitMessage](), err
 	}
-	hashes := stringslice.Lines(output)
-	if len(hashes) == 0 {
+	lines := stringslice.Lines(output)
+	if len(lines) == 0 {
 		return None[gitdomain.CommitMessage](), nil
 	}
-	hash := hashes[len(hashes)-1]
-	message, err := runner.QueryTrim("git", "log", "--format=%B", "-n", "1", hash)
-	if err != nil {
-		return None[gitdomain.CommitMessage](), err
-	}
-	return Some(gitdomain.CommitMessage(message)), nil
+	return Some(gitdomain.CommitMessage(lines[0])), nil
 }
 
 func (self *Commands) FirstExistingBranch(runner gitdomain.Runner, branches ...gitdomain.LocalBranchName) Option[gitdomain.LocalBranchName] {
@@ -536,8 +592,8 @@ func (self *Commands) RemoveGiteaToken(runner gitdomain.Runner) error {
 	return runner.Run("git", "config", "--unset", configdomain.KeyGiteaToken.String())
 }
 
-// RenameBranch renames the branch with the given old name to the branch with the given new name.
-func (self *Commands) RenameBranch(runner gitdomain.Runner, oldName, newName gitdomain.LocalBranchName) error {
+// Rename renames the branch with the given old name to the branch with the given new name.
+func (self *Commands) Rename(runner gitdomain.Runner, oldName, newName gitdomain.LocalBranchName) error {
 	return runner.Run("git", "branch", "--move", oldName.String(), newName.String())
 }
 
@@ -691,19 +747,19 @@ func (self *Commands) Version(querier gitdomain.Querier) (Version, error) {
 	versionRegexp := regexp.MustCompile(`git version (\d+).(\d+).(\d+)`)
 	output, err := querier.QueryTrim("git", "version")
 	if err != nil {
-		return emptyVersion(), fmt.Errorf(messages.GitVersionProblem, err)
+		return EmptyVersion(), fmt.Errorf(messages.GitVersionProblem, err)
 	}
 	matches := versionRegexp.FindStringSubmatch(output)
 	if matches == nil {
-		return emptyVersion(), fmt.Errorf(messages.GitVersionUnexpectedOutput, output)
+		return EmptyVersion(), fmt.Errorf(messages.GitVersionUnexpectedOutput, output)
 	}
 	majorVersion, err := strconv.Atoi(matches[1])
 	if err != nil {
-		return emptyVersion(), fmt.Errorf(messages.GitVersionMajorNotNumber, matches[1], err)
+		return EmptyVersion(), fmt.Errorf(messages.GitVersionMajorNotNumber, matches[1], err)
 	}
 	minorVersion, err := strconv.Atoi(matches[2])
 	if err != nil {
-		return emptyVersion(), fmt.Errorf(messages.GitVersionMinorNotNumber, matches[2], err)
+		return EmptyVersion(), fmt.Errorf(messages.GitVersionMinorNotNumber, matches[2], err)
 	}
 	return Version{
 		Major: majorVersion,
@@ -784,6 +840,15 @@ func LastBranchInRef(output string) string {
 	return output[index+1:]
 }
 
+func NewUnmergedStage(value int) (UnmergedStage, error) {
+	for _, stage := range UnmergedStages {
+		if int(stage) == value {
+			return stage, nil
+		}
+	}
+	return 0, fmt.Errorf("unknown stage ID: %q", value)
+}
+
 func ParseActiveBranchDuringRebase(lineWithStar string) gitdomain.LocalBranchName {
 	parts := strings.Split(lineWithStar, " ")
 	partsWithBranchName := parts[4:]
