@@ -12,6 +12,14 @@ import (
 // they are listed in the `TrackingBranch` property of the local branch they track.
 type BranchInfos []BranchInfo
 
+func (self BranchInfos) BranchIsActiveInAnotherWorktree(branch LocalBranchName) bool {
+	branchInfo, has := self.FindByLocalName(branch).Get()
+	if !has {
+		return false
+	}
+	return branchInfo.SyncStatus == SyncStatusOtherWorktree
+}
+
 // FindByLocalName provides the branch with the given name if one exists.
 func (self BranchInfos) FindByLocalName(branchName LocalBranchName) OptionP[BranchInfo] {
 	for bi, branch := range self {
@@ -37,6 +45,19 @@ func (self BranchInfos) FindByRemoteName(remoteBranch RemoteBranchName) OptionP[
 	return NoneP[BranchInfo]()
 }
 
+func (self BranchInfos) FindLocalOrRemote(branchName LocalBranchName) OptionP[BranchInfo] {
+	branchInfoOpt := self.FindByLocalName(branchName)
+	if branchInfoOpt.IsSome() {
+		return branchInfoOpt
+	}
+	remoteName := branchName.AtRemote(RemoteOrigin)
+	branchInfoOpt = self.FindByRemoteName(remoteName)
+	if branchInfoOpt.IsSome() {
+		return branchInfoOpt
+	}
+	return NoneP[BranchInfo]()
+}
+
 func (self BranchInfos) FindMatchingRecord(other BranchInfo) OptionP[BranchInfo] {
 	for b, bi := range self {
 		biLocalName, hasBiLocalName := bi.LocalName.Get()
@@ -128,11 +149,16 @@ func (self BranchInfos) Remove(branchName LocalBranchName) BranchInfos {
 func (self BranchInfos) Select(names ...LocalBranchName) (BranchInfos, error) {
 	result := make(BranchInfos, len(names))
 	for n, name := range names {
-		if branch, hasBranch := self.FindByLocalName(name).Get(); hasBranch {
-			result[n] = *branch
-		} else {
-			return result, fmt.Errorf(messages.BranchDoesntExist, name)
+		if branchInfo, has := self.FindByLocalName(name).Get(); has {
+			result[n] = *branchInfo
+			continue
 		}
+		remoteName := name.AtRemote(RemoteOrigin)
+		if branchInfo, has := self.FindByRemoteName(remoteName).Get(); has {
+			result[n] = *branchInfo
+			continue
+		}
+		return result, fmt.Errorf(messages.BranchDoesntExist, name)
 	}
 	return result, nil
 }
