@@ -3,6 +3,7 @@ package undobranches_test
 import (
 	"testing"
 
+	"github.com/git-town/git-town/v16/internal/config"
 	"github.com/git-town/git-town/v16/internal/config/configdomain"
 	"github.com/git-town/git-town/v16/internal/git/gitdomain"
 	"github.com/git-town/git-town/v16/internal/undo/undobranches"
@@ -62,24 +63,28 @@ func TestChanges(t *testing.T) {
 		}
 		must.Eq(t, wantChanges, haveChanges)
 		lineage := configdomain.NewLineage()
-		lineage.Add(gitdomain.NewLocalBranchName("branch-1"), gitdomain.NewLocalBranchName("main"))
-		config := configdomain.ValidatedConfig{
-			MainBranch: gitdomain.NewLocalBranchName("main"),
-			UnvalidatedConfig: &configdomain.UnvalidatedConfig{
-				Lineage:           lineage,
-				PushHook:          false,
-				PerennialBranches: gitdomain.NewLocalBranchNames(),
+		lineage.Add("branch-1", "main")
+		config := config.ValidatedConfig{
+			ValidatedConfigData: configdomain.ValidatedConfigData{
+				MainBranch: "main",
+			},
+			NormalConfig: config.NormalConfig{
+				NormalConfigData: configdomain.NormalConfigData{
+					Lineage:           lineage,
+					PushHook:          false,
+					PerennialBranches: gitdomain.LocalBranchNames{},
+				},
 			},
 		}
 		haveProgram := haveChanges.UndoProgram(undobranches.BranchChangesUndoProgramArgs{
 			BeginBranch:              before.Active.GetOrPanic(),
 			Config:                   config,
 			EndBranch:                after.Active.GetOrPanic(),
-			UndoablePerennialCommits: []gitdomain.SHA(nil),
+			UndoablePerennialCommits: []gitdomain.SHA{},
 		})
 		wantProgram := program.Program{
 			&opcodes.CheckoutIfNeeded{Branch: gitdomain.NewLocalBranchName("main")},
-			&opcodes.DeleteLocalBranch{Branch: gitdomain.NewLocalBranchName("branch-1")},
+			&opcodes.BranchLocalDelete{Branch: gitdomain.NewLocalBranchName("branch-1")},
 			&opcodes.CheckoutIfExists{Branch: gitdomain.NewLocalBranchName("main")},
 		}
 		must.Eq(t, wantProgram, haveProgram)
@@ -119,22 +124,26 @@ func TestChanges(t *testing.T) {
 			InconsistentlyChanged: undodomain.InconsistentChanges{},
 		}
 		must.Eq(t, wantChanges, haveChanges)
-		config := configdomain.ValidatedConfig{
-			MainBranch: gitdomain.NewLocalBranchName("main"),
-			UnvalidatedConfig: &configdomain.UnvalidatedConfig{
-				Lineage:           configdomain.Lineage{},
-				PerennialBranches: gitdomain.NewLocalBranchNames(),
-				PushHook:          false,
+		config := config.ValidatedConfig{
+			ValidatedConfigData: configdomain.ValidatedConfigData{
+				MainBranch: "main",
+			},
+			NormalConfig: config.NormalConfig{
+				NormalConfigData: configdomain.NormalConfigData{
+					Lineage:           configdomain.Lineage{},
+					PerennialBranches: gitdomain.LocalBranchNames{},
+					PushHook:          false,
+				},
 			},
 		}
 		haveProgram := haveChanges.UndoProgram(undobranches.BranchChangesUndoProgramArgs{
 			BeginBranch:              before.Active.GetOrPanic(),
 			Config:                   config,
 			EndBranch:                after.Active.GetOrPanic(),
-			UndoablePerennialCommits: []gitdomain.SHA(nil),
+			UndoablePerennialCommits: []gitdomain.SHA{},
 		})
 		wantProgram := program.Program{
-			&opcodes.CreateBranch{
+			&opcodes.BranchCreate{
 				Branch:        gitdomain.NewLocalBranchName("branch-1"),
 				StartingPoint: gitdomain.NewSHA("111111").Location(),
 			},
@@ -208,30 +217,34 @@ func TestChanges(t *testing.T) {
 		}
 		must.Eq(t, wantChanges, haveChanges)
 		lineage := configdomain.NewLineage()
-		lineage.Add(gitdomain.NewLocalBranchName("feature-branch"), gitdomain.NewLocalBranchName("main"))
-		config := configdomain.ValidatedConfig{
-			MainBranch: gitdomain.NewLocalBranchName("main"),
-			UnvalidatedConfig: &configdomain.UnvalidatedConfig{
-				PerennialBranches: gitdomain.NewLocalBranchNames("perennial-branch"),
-				Lineage:           lineage,
-				PushHook:          false,
+		lineage.Add("feature-branch", "main")
+		config := config.ValidatedConfig{
+			ValidatedConfigData: configdomain.ValidatedConfigData{
+				MainBranch: "main",
+			},
+			NormalConfig: config.NormalConfig{
+				NormalConfigData: configdomain.NormalConfigData{
+					PerennialBranches: gitdomain.NewLocalBranchNames("perennial-branch"),
+					Lineage:           lineage,
+					PushHook:          false,
+				},
 			},
 		}
 		haveProgram := haveChanges.UndoProgram(undobranches.BranchChangesUndoProgramArgs{
 			BeginBranch:              before.Active.GetOrPanic(),
 			Config:                   config,
 			EndBranch:                after.Active.GetOrPanic(),
-			UndoablePerennialCommits: []gitdomain.SHA(nil),
+			UndoablePerennialCommits: []gitdomain.SHA{},
 		})
 		wantProgram := program.Program{
 			&opcodes.CheckoutIfNeeded{Branch: gitdomain.NewLocalBranchName("feature-branch")},
-			&opcodes.ResetCurrentBranchToSHAIfNeeded{
+			&opcodes.BranchCurrentResetToSHAIfNeeded{
 				MustHaveSHA: gitdomain.NewSHA("444444"),
 				SetToSHA:    gitdomain.NewSHA("222222"),
 				Hard:        true,
 			},
 			&opcodes.CheckoutIfNeeded{Branch: gitdomain.NewLocalBranchName("perennial-branch")},
-			&opcodes.ResetCurrentBranchToSHAIfNeeded{
+			&opcodes.BranchCurrentResetToSHAIfNeeded{
 				MustHaveSHA: gitdomain.NewSHA("333333"),
 				SetToSHA:    gitdomain.NewSHA("111111"),
 				Hard:        true,
@@ -299,26 +312,30 @@ func TestChanges(t *testing.T) {
 		}
 		must.Eq(t, wantChanges, haveChanges)
 		lineage := configdomain.NewLineage()
-		lineage.Add(gitdomain.NewLocalBranchName("feature-branch"), gitdomain.NewLocalBranchName("main"))
-		config := configdomain.ValidatedConfig{
-			MainBranch: gitdomain.NewLocalBranchName("main"),
-			UnvalidatedConfig: &configdomain.UnvalidatedConfig{
-				Lineage:           lineage,
-				PerennialBranches: gitdomain.NewLocalBranchNames("perennial-branch"),
-				PushHook:          false,
+		lineage.Add("feature-branch", "main")
+		config := config.ValidatedConfig{
+			ValidatedConfigData: configdomain.ValidatedConfigData{
+				MainBranch: "main",
+			},
+			NormalConfig: config.NormalConfig{
+				NormalConfigData: configdomain.NormalConfigData{
+					Lineage:           lineage,
+					PerennialBranches: gitdomain.NewLocalBranchNames("perennial-branch"),
+					PushHook:          false,
+				},
 			},
 		}
 		haveProgram := haveChanges.UndoProgram(undobranches.BranchChangesUndoProgramArgs{
 			BeginBranch:              before.Active.GetOrPanic(),
 			Config:                   config,
 			EndBranch:                after.Active.GetOrPanic(),
-			UndoablePerennialCommits: []gitdomain.SHA(nil),
+			UndoablePerennialCommits: []gitdomain.SHA{},
 		})
 		wantProgram := program.Program{
-			&opcodes.DeleteTrackingBranch{
+			&opcodes.BranchTrackingDelete{
 				Branch: gitdomain.NewRemoteBranchName("origin/perennial-branch"),
 			},
-			&opcodes.DeleteTrackingBranch{
+			&opcodes.BranchTrackingDelete{
 				Branch: gitdomain.NewRemoteBranchName("origin/feature-branch"),
 			},
 			&opcodes.CheckoutIfExists{Branch: gitdomain.NewLocalBranchName("feature-branch")},
@@ -384,24 +401,28 @@ func TestChanges(t *testing.T) {
 		}
 		must.Eq(t, wantChanges, haveChanges)
 		lineage := configdomain.NewLineage()
-		lineage.Add(gitdomain.NewLocalBranchName("feature-branch"), gitdomain.NewLocalBranchName("main"))
-		config := configdomain.ValidatedConfig{
-			MainBranch: gitdomain.NewLocalBranchName("main"),
-			UnvalidatedConfig: &configdomain.UnvalidatedConfig{
-				Lineage:           lineage,
-				PerennialBranches: gitdomain.NewLocalBranchNames("perennial-branch"),
-				PushHook:          false,
+		lineage.Add("feature-branch", "main")
+		config := config.ValidatedConfig{
+			ValidatedConfigData: configdomain.ValidatedConfigData{
+				MainBranch: "main",
+			},
+			NormalConfig: config.NormalConfig{
+				NormalConfigData: configdomain.NormalConfigData{
+					Lineage:           lineage,
+					PerennialBranches: gitdomain.NewLocalBranchNames("perennial-branch"),
+					PushHook:          false,
+				},
 			},
 		}
 		haveProgram := haveChanges.UndoProgram(undobranches.BranchChangesUndoProgramArgs{
 			BeginBranch:              before.Active.GetOrPanic(),
 			Config:                   config,
 			EndBranch:                after.Active.GetOrPanic(),
-			UndoablePerennialCommits: []gitdomain.SHA(nil),
+			UndoablePerennialCommits: []gitdomain.SHA{},
 		})
 		wantProgram := program.Program{
-			&opcodes.DeleteLocalBranch{Branch: gitdomain.NewLocalBranchName("perennial-branch")},
-			&opcodes.DeleteLocalBranch{Branch: gitdomain.NewLocalBranchName("feature-branch")},
+			&opcodes.BranchLocalDelete{Branch: gitdomain.NewLocalBranchName("perennial-branch")},
+			&opcodes.BranchLocalDelete{Branch: gitdomain.NewLocalBranchName("feature-branch")},
 			&opcodes.CheckoutIfExists{Branch: gitdomain.NewLocalBranchName("main")},
 		}
 		must.Eq(t, wantProgram, haveProgram)
@@ -453,29 +474,33 @@ func TestChanges(t *testing.T) {
 		}
 		must.Eq(t, wantChanges, haveChanges)
 		lineage := configdomain.NewLineage()
-		lineage.Add(gitdomain.NewLocalBranchName("feature-branch"), gitdomain.NewLocalBranchName("main"))
-		config := configdomain.ValidatedConfig{
-			MainBranch: gitdomain.NewLocalBranchName("main"),
-			UnvalidatedConfig: &configdomain.UnvalidatedConfig{
-				Lineage:           lineage,
-				PerennialBranches: gitdomain.NewLocalBranchNames("perennial-branch"),
-				PushHook:          false,
+		lineage.Add("feature-branch", "main")
+		config := config.ValidatedConfig{
+			ValidatedConfigData: configdomain.ValidatedConfigData{
+				MainBranch: "main",
+			},
+			NormalConfig: config.NormalConfig{
+				NormalConfigData: configdomain.NormalConfigData{
+					Lineage:           lineage,
+					PerennialBranches: gitdomain.NewLocalBranchNames("perennial-branch"),
+					PushHook:          false,
+				},
 			},
 		}
 		haveProgram := haveChanges.UndoProgram(undobranches.BranchChangesUndoProgramArgs{
 			BeginBranch:              before.Active.GetOrPanic(),
 			Config:                   config,
 			EndBranch:                after.Active.GetOrPanic(),
-			UndoablePerennialCommits: []gitdomain.SHA(nil),
+			UndoablePerennialCommits: []gitdomain.SHA{},
 		})
 		wantProgram := program.Program{
-			&opcodes.DeleteLocalBranch{Branch: gitdomain.NewLocalBranchName("perennial-branch")},
+			&opcodes.BranchLocalDelete{Branch: gitdomain.NewLocalBranchName("perennial-branch")},
 			&opcodes.CheckoutIfNeeded{Branch: gitdomain.NewLocalBranchName("main")},
-			&opcodes.DeleteLocalBranch{Branch: gitdomain.NewLocalBranchName("feature-branch")},
-			&opcodes.DeleteTrackingBranch{
+			&opcodes.BranchLocalDelete{Branch: gitdomain.NewLocalBranchName("feature-branch")},
+			&opcodes.BranchTrackingDelete{
 				Branch: gitdomain.NewRemoteBranchName("origin/perennial-branch"),
 			},
-			&opcodes.DeleteTrackingBranch{
+			&opcodes.BranchTrackingDelete{
 				Branch: gitdomain.NewRemoteBranchName("origin/feature-branch"),
 			},
 			&opcodes.CheckoutIfExists{Branch: gitdomain.NewLocalBranchName("main")},
@@ -547,30 +572,34 @@ func TestChanges(t *testing.T) {
 		}
 		must.Eq(t, wantChanges, haveChanges)
 		lineage := configdomain.NewLineage()
-		lineage.Add(gitdomain.NewLocalBranchName("feature-branch"), gitdomain.NewLocalBranchName("main"))
-		config := configdomain.ValidatedConfig{
-			MainBranch: gitdomain.NewLocalBranchName("main"),
-			UnvalidatedConfig: &configdomain.UnvalidatedConfig{
-				Lineage:           lineage,
-				PerennialBranches: gitdomain.NewLocalBranchNames("perennial-branch"),
-				PushHook:          true,
+		lineage.Add("feature-branch", "main")
+		config := config.ValidatedConfig{
+			ValidatedConfigData: configdomain.ValidatedConfigData{
+				MainBranch: "main",
+			},
+			NormalConfig: config.NormalConfig{
+				NormalConfigData: configdomain.NormalConfigData{
+					Lineage:           lineage,
+					PerennialBranches: gitdomain.NewLocalBranchNames("perennial-branch"),
+					PushHook:          true,
+				},
 			},
 		}
 		haveProgram := haveChanges.UndoProgram(undobranches.BranchChangesUndoProgramArgs{
 			BeginBranch:              before.Active.GetOrPanic(),
 			Config:                   config,
 			EndBranch:                after.Active.GetOrPanic(),
-			UndoablePerennialCommits: []gitdomain.SHA(nil),
+			UndoablePerennialCommits: []gitdomain.SHA{},
 		})
 		wantProgram := program.Program{
 			&opcodes.CheckoutIfNeeded{Branch: gitdomain.NewLocalBranchName("feature-branch")},
-			&opcodes.ResetCurrentBranchToSHAIfNeeded{
+			&opcodes.BranchCurrentResetToSHAIfNeeded{
 				MustHaveSHA: gitdomain.NewSHA("444444"),
 				SetToSHA:    gitdomain.NewSHA("222222"),
 				Hard:        true,
 			},
 			&opcodes.CheckoutIfNeeded{Branch: gitdomain.NewLocalBranchName("perennial-branch")},
-			&opcodes.ResetCurrentBranchToSHAIfNeeded{
+			&opcodes.BranchCurrentResetToSHAIfNeeded{
 				MustHaveSHA: gitdomain.NewSHA("333333"),
 				SetToSHA:    gitdomain.NewSHA("111111"),
 				Hard:        true,
@@ -679,25 +708,29 @@ func TestChanges(t *testing.T) {
 		}
 		must.Eq(t, wantChanges, haveChanges)
 		lineage := configdomain.NewLineage()
-		lineage.Add(gitdomain.NewLocalBranchName("feature-branch"), gitdomain.NewLocalBranchName("main"))
-		config := configdomain.ValidatedConfig{
-			MainBranch: gitdomain.NewLocalBranchName("main"),
-			UnvalidatedConfig: &configdomain.UnvalidatedConfig{
-				Lineage:           lineage,
-				PerennialBranches: gitdomain.NewLocalBranchNames("perennial-branch"),
-				PushHook:          true,
+		lineage.Add("feature-branch", "main")
+		config := config.ValidatedConfig{
+			ValidatedConfigData: configdomain.ValidatedConfigData{
+				MainBranch: "main",
+			},
+			NormalConfig: config.NormalConfig{
+				NormalConfigData: configdomain.NormalConfigData{
+					Lineage:           lineage,
+					PerennialBranches: gitdomain.NewLocalBranchNames("perennial-branch"),
+					PushHook:          true,
+				},
 			},
 		}
 		haveProgram := haveChanges.UndoProgram(undobranches.BranchChangesUndoProgramArgs{
 			BeginBranch:              before.Active.GetOrPanic(),
 			Config:                   config,
 			EndBranch:                after.Active.GetOrPanic(),
-			UndoablePerennialCommits: []gitdomain.SHA(nil),
+			UndoablePerennialCommits: []gitdomain.SHA{},
 		})
 		wantProgram := program.Program{
 			// It doesn't reset the remote perennial branch since those are assumed to be protected against force-pushes
 			// and we can't revert the commit on it since we cannot change the local perennial branch here.
-			&opcodes.ResetRemoteBranchToSHAIfNeeded{
+			&opcodes.BranchRemoteSetToSHAIfNeeded{
 				Branch:      gitdomain.NewRemoteBranchName("origin/feature-branch"),
 				SetToSHA:    gitdomain.NewSHA("333333"),
 				MustHaveSHA: gitdomain.NewSHA("444444"),
@@ -789,13 +822,17 @@ func TestChanges(t *testing.T) {
 		}
 		must.Eq(t, wantChanges, haveChanges)
 		lineage := configdomain.NewLineage()
-		lineage.Add(gitdomain.NewLocalBranchName("feature-branch"), gitdomain.NewLocalBranchName("main"))
-		config := configdomain.ValidatedConfig{
-			MainBranch: gitdomain.NewLocalBranchName("main"),
-			UnvalidatedConfig: &configdomain.UnvalidatedConfig{
-				Lineage:           lineage,
-				PerennialBranches: gitdomain.NewLocalBranchNames("perennial-branch"),
-				PushHook:          false,
+		lineage.Add("feature-branch", "main")
+		config := config.ValidatedConfig{
+			ValidatedConfigData: configdomain.ValidatedConfigData{
+				MainBranch: "main",
+			},
+			NormalConfig: config.NormalConfig{
+				NormalConfigData: configdomain.NormalConfigData{
+					Lineage:           lineage,
+					PerennialBranches: gitdomain.NewLocalBranchNames("perennial-branch"),
+					PushHook:          false,
+				},
 			},
 		}
 		haveProgram := haveChanges.UndoProgram(undobranches.BranchChangesUndoProgramArgs{
@@ -809,12 +846,12 @@ func TestChanges(t *testing.T) {
 		wantProgram := program.Program{
 			// revert the commit on the perennial branch
 			&opcodes.CheckoutIfNeeded{Branch: gitdomain.NewLocalBranchName("main")},
-			&opcodes.RevertCommitIfNeeded{SHA: gitdomain.NewSHA("444444")},
+			&opcodes.CommitRevertIfNeeded{SHA: gitdomain.NewSHA("444444")},
 			&opcodes.PushCurrentBranchIfNeeded{CurrentBranch: gitdomain.NewLocalBranchName("main")},
 			// reset the feature branch to the previous SHA
 			&opcodes.CheckoutIfNeeded{Branch: gitdomain.NewLocalBranchName("feature-branch")},
-			&opcodes.ResetCurrentBranchToSHAIfNeeded{MustHaveSHA: gitdomain.NewSHA("666666"), SetToSHA: gitdomain.NewSHA("333333"), Hard: true},
-			&opcodes.ForcePushCurrentBranch{ForceIfIncludes: true},
+			&opcodes.BranchCurrentResetToSHAIfNeeded{MustHaveSHA: gitdomain.NewSHA("666666"), SetToSHA: gitdomain.NewSHA("333333"), Hard: true},
+			&opcodes.PushCurrentBranchForceIfNeeded{ForceIfIncludes: true},
 			// check out the initial branch
 			&opcodes.CheckoutIfExists{Branch: gitdomain.NewLocalBranchName("feature-branch")},
 		}
@@ -890,13 +927,17 @@ func TestChanges(t *testing.T) {
 		}
 		must.Eq(t, wantChanges, haveChanges)
 		lineage := configdomain.NewLineage()
-		lineage.Add(gitdomain.NewLocalBranchName("feature-branch"), gitdomain.NewLocalBranchName("main"))
-		config := configdomain.ValidatedConfig{
-			MainBranch: gitdomain.NewLocalBranchName("main"),
-			UnvalidatedConfig: &configdomain.UnvalidatedConfig{
-				Lineage:           lineage,
-				PerennialBranches: gitdomain.NewLocalBranchNames("perennial-branch"),
-				PushHook:          false,
+		lineage.Add("feature-branch", "main")
+		config := config.ValidatedConfig{
+			ValidatedConfigData: configdomain.ValidatedConfigData{
+				MainBranch: "main",
+			},
+			NormalConfig: config.NormalConfig{
+				NormalConfigData: configdomain.NormalConfigData{
+					Lineage:           lineage,
+					PerennialBranches: gitdomain.NewLocalBranchNames("perennial-branch"),
+					PushHook:          false,
+				},
 			},
 		}
 		haveProgram := haveChanges.UndoProgram(undobranches.BranchChangesUndoProgramArgs{
@@ -910,11 +951,11 @@ func TestChanges(t *testing.T) {
 		wantProgram := program.Program{
 			// revert the undoable commit on the main branch
 			&opcodes.CheckoutIfNeeded{Branch: gitdomain.NewLocalBranchName("main")},
-			&opcodes.RevertCommitIfNeeded{SHA: gitdomain.NewSHA("444444")},
+			&opcodes.CommitRevertIfNeeded{SHA: gitdomain.NewSHA("444444")},
 			&opcodes.PushCurrentBranchIfNeeded{CurrentBranch: gitdomain.NewLocalBranchName("main")},
 			// re-create the feature branch
-			&opcodes.CreateBranch{Branch: gitdomain.NewLocalBranchName("feature-branch"), StartingPoint: gitdomain.NewSHA("222222").Location()},
-			&opcodes.CreateTrackingBranch{Branch: gitdomain.NewLocalBranchName("feature-branch")},
+			&opcodes.BranchCreate{Branch: gitdomain.NewLocalBranchName("feature-branch"), StartingPoint: gitdomain.NewSHA("222222").Location()},
+			&opcodes.BranchTrackingCreate{Branch: gitdomain.NewLocalBranchName("feature-branch")},
 			// check out the initial branch
 			&opcodes.CheckoutIfExists{Branch: gitdomain.NewLocalBranchName("feature-branch")},
 		}
@@ -1009,30 +1050,34 @@ func TestChanges(t *testing.T) {
 		}
 		must.Eq(t, wantChanges, haveChanges)
 		lineage := configdomain.NewLineage()
-		lineage.Add(gitdomain.NewLocalBranchName("feature-branch"), gitdomain.NewLocalBranchName("main"))
-		config := configdomain.ValidatedConfig{
-			MainBranch: gitdomain.NewLocalBranchName("main"),
-			UnvalidatedConfig: &configdomain.UnvalidatedConfig{
-				Lineage:           lineage,
-				PerennialBranches: gitdomain.NewLocalBranchNames("perennial-branch"),
-				PushHook:          false,
+		lineage.Add("feature-branch", "main")
+		config := config.ValidatedConfig{
+			ValidatedConfigData: configdomain.ValidatedConfigData{
+				MainBranch: "main",
+			},
+			NormalConfig: config.NormalConfig{
+				NormalConfigData: configdomain.NormalConfigData{
+					Lineage:           lineage,
+					PerennialBranches: gitdomain.NewLocalBranchNames("perennial-branch"),
+					PushHook:          false,
+				},
 			},
 		}
 		haveProgram := haveChanges.UndoProgram(undobranches.BranchChangesUndoProgramArgs{
 			BeginBranch:              before.Active.GetOrPanic(),
 			Config:                   config,
 			EndBranch:                after.Active.GetOrPanic(),
-			UndoablePerennialCommits: []gitdomain.SHA(nil),
+			UndoablePerennialCommits: []gitdomain.SHA{},
 		})
 		wantProgram := program.Program{
 			// It doesn't revert the perennial branch because it cannot force-push the changes to the remote branch.
 			&opcodes.CheckoutIfNeeded{Branch: gitdomain.NewLocalBranchName("feature-branch")},
-			&opcodes.ResetCurrentBranchToSHAIfNeeded{
+			&opcodes.BranchCurrentResetToSHAIfNeeded{
 				MustHaveSHA: gitdomain.NewSHA("555555"),
 				SetToSHA:    gitdomain.NewSHA("222222"),
 				Hard:        true,
 			},
-			&opcodes.ResetRemoteBranchToSHAIfNeeded{
+			&opcodes.BranchRemoteSetToSHAIfNeeded{
 				Branch:      gitdomain.NewRemoteBranchName("origin/feature-branch"),
 				MustHaveSHA: gitdomain.NewSHA("666666"),
 				SetToSHA:    gitdomain.NewSHA("222222"),
@@ -1106,30 +1151,34 @@ func TestChanges(t *testing.T) {
 		}
 		must.Eq(t, wantChanges, haveChanges)
 		lineage := configdomain.NewLineage()
-		lineage.Add(gitdomain.NewLocalBranchName("feature-branch"), gitdomain.NewLocalBranchName("main"))
-		config := configdomain.ValidatedConfig{
-			MainBranch: gitdomain.NewLocalBranchName("main"),
-			UnvalidatedConfig: &configdomain.UnvalidatedConfig{
-				Lineage:           lineage,
-				PerennialBranches: gitdomain.NewLocalBranchNames("perennial-branch"),
-				PushHook:          false,
+		lineage.Add("feature-branch", "main")
+		config := config.ValidatedConfig{
+			ValidatedConfigData: configdomain.ValidatedConfigData{
+				MainBranch: "main",
+			},
+			NormalConfig: config.NormalConfig{
+				NormalConfigData: configdomain.NormalConfigData{
+					Lineage:           lineage,
+					PerennialBranches: gitdomain.NewLocalBranchNames("perennial-branch"),
+					PushHook:          false,
+				},
 			},
 		}
 		haveProgram := haveChanges.UndoProgram(undobranches.BranchChangesUndoProgramArgs{
 			BeginBranch:              before.Active.GetOrPanic(),
 			Config:                   config,
 			EndBranch:                after.Active.GetOrPanic(),
-			UndoablePerennialCommits: []gitdomain.SHA(nil),
+			UndoablePerennialCommits: []gitdomain.SHA{},
 		})
 		wantProgram := program.Program{
 			&opcodes.CheckoutIfNeeded{Branch: gitdomain.NewLocalBranchName("feature-branch")},
-			&opcodes.ResetCurrentBranchToSHAIfNeeded{
+			&opcodes.BranchCurrentResetToSHAIfNeeded{
 				MustHaveSHA: gitdomain.NewSHA("444444"),
 				SetToSHA:    gitdomain.NewSHA("333333"),
 				Hard:        true,
 			},
 			&opcodes.CheckoutIfNeeded{Branch: gitdomain.NewLocalBranchName("perennial-branch")},
-			&opcodes.ResetCurrentBranchToSHAIfNeeded{
+			&opcodes.BranchCurrentResetToSHAIfNeeded{
 				MustHaveSHA: gitdomain.NewSHA("222222"),
 				SetToSHA:    gitdomain.NewSHA("111111"),
 				Hard:        true,
@@ -1203,24 +1252,28 @@ func TestChanges(t *testing.T) {
 		}
 		must.Eq(t, wantChanges, haveChanges)
 		lineage := configdomain.NewLineage()
-		lineage.Add(gitdomain.NewLocalBranchName("feature-branch"), gitdomain.NewLocalBranchName("main"))
-		config := configdomain.ValidatedConfig{
-			MainBranch: gitdomain.NewLocalBranchName("main"),
-			UnvalidatedConfig: &configdomain.UnvalidatedConfig{
-				Lineage:           lineage,
-				PerennialBranches: gitdomain.NewLocalBranchNames("perennial-branch"),
-				PushHook:          false,
+		lineage.Add("feature-branch", "main")
+		config := config.ValidatedConfig{
+			ValidatedConfigData: configdomain.ValidatedConfigData{
+				MainBranch: "main",
+			},
+			NormalConfig: config.NormalConfig{
+				NormalConfigData: configdomain.NormalConfigData{
+					Lineage:           lineage,
+					PerennialBranches: gitdomain.NewLocalBranchNames("perennial-branch"),
+					PushHook:          false,
+				},
 			},
 		}
 		haveProgram := haveChanges.UndoProgram(undobranches.BranchChangesUndoProgramArgs{
 			BeginBranch:              before.Active.GetOrPanic(),
 			Config:                   config,
 			EndBranch:                after.Active.GetOrPanic(),
-			UndoablePerennialCommits: []gitdomain.SHA(nil),
+			UndoablePerennialCommits: []gitdomain.SHA{},
 		})
 		wantProgram := program.Program{
 			// It doesn't revert the remote perennial branch because it cannot force-push the changes to it.
-			&opcodes.ResetRemoteBranchToSHAIfNeeded{
+			&opcodes.BranchRemoteSetToSHAIfNeeded{
 				Branch:      gitdomain.NewRemoteBranchName("origin/feature-branch"),
 				MustHaveSHA: gitdomain.NewSHA("444444"),
 				SetToSHA:    gitdomain.NewSHA("333333"),
@@ -1288,27 +1341,31 @@ func TestChanges(t *testing.T) {
 		}
 		must.Eq(t, wantChanges, haveChanges)
 		lineage := configdomain.NewLineage()
-		lineage.Add(gitdomain.NewLocalBranchName("feature-branch"), gitdomain.NewLocalBranchName("main"))
-		config := configdomain.ValidatedConfig{
-			MainBranch: gitdomain.NewLocalBranchName("main"),
-			UnvalidatedConfig: &configdomain.UnvalidatedConfig{
-				Lineage:           lineage,
-				PerennialBranches: gitdomain.NewLocalBranchNames("perennial-branch"),
-				PushHook:          false,
+		lineage.Add("feature-branch", "main")
+		config := config.ValidatedConfig{
+			ValidatedConfigData: configdomain.ValidatedConfigData{
+				MainBranch: "main",
+			},
+			NormalConfig: config.NormalConfig{
+				NormalConfigData: configdomain.NormalConfigData{
+					Lineage:           lineage,
+					PerennialBranches: gitdomain.NewLocalBranchNames("perennial-branch"),
+					PushHook:          false,
+				},
 			},
 		}
 		haveProgram := haveChanges.UndoProgram(undobranches.BranchChangesUndoProgramArgs{
 			BeginBranch:              before.Active.GetOrPanic(),
 			Config:                   config,
 			EndBranch:                after.Active.GetOrPanic(),
-			UndoablePerennialCommits: []gitdomain.SHA(nil),
+			UndoablePerennialCommits: []gitdomain.SHA{},
 		})
 		wantProgram := program.Program{
-			&opcodes.CreateBranch{
+			&opcodes.BranchCreate{
 				Branch:        gitdomain.NewLocalBranchName("feature-branch"),
 				StartingPoint: gitdomain.NewSHA("222222").Location(),
 			},
-			&opcodes.CreateBranch{
+			&opcodes.BranchCreate{
 				Branch:        gitdomain.NewLocalBranchName("perennial-branch"),
 				StartingPoint: gitdomain.NewSHA("111111").Location(),
 			},
@@ -1375,25 +1432,29 @@ func TestChanges(t *testing.T) {
 		}
 		must.Eq(t, wantChanges, haveChanges)
 		lineage := configdomain.NewLineage()
-		lineage.Add(gitdomain.NewLocalBranchName("feature-branch"), gitdomain.NewLocalBranchName("main"))
-		config := configdomain.ValidatedConfig{
-			MainBranch: gitdomain.NewLocalBranchName("main"),
-			UnvalidatedConfig: &configdomain.UnvalidatedConfig{
-				Lineage:           lineage,
-				PerennialBranches: gitdomain.NewLocalBranchNames("perennial-branch"),
-				PushHook:          false,
+		lineage.Add("feature-branch", "main")
+		config := config.ValidatedConfig{
+			ValidatedConfigData: configdomain.ValidatedConfigData{
+				MainBranch: "main",
+			},
+			NormalConfig: config.NormalConfig{
+				NormalConfigData: configdomain.NormalConfigData{
+					Lineage:           lineage,
+					PerennialBranches: gitdomain.NewLocalBranchNames("perennial-branch"),
+					PushHook:          false,
+				},
 			},
 		}
 		haveProgram := haveChanges.UndoProgram(undobranches.BranchChangesUndoProgramArgs{
 			BeginBranch:              before.Active.GetOrPanic(),
 			Config:                   config,
 			EndBranch:                after.Active.GetOrDefault(),
-			UndoablePerennialCommits: []gitdomain.SHA(nil),
+			UndoablePerennialCommits: []gitdomain.SHA{},
 		})
 		wantProgram := program.Program{
 			// don't re-create the tracking branch for the perennial branch
 			// because those are protected
-			&opcodes.CreateRemoteBranch{
+			&opcodes.BranchRemoteCreate{
 				Branch: gitdomain.NewLocalBranchName("feature-branch"),
 				SHA:    gitdomain.NewSHA("222222"),
 			},
@@ -1457,20 +1518,24 @@ func TestChanges(t *testing.T) {
 		}
 		must.Eq(t, wantChanges, haveChanges)
 		lineage := configdomain.NewLineage()
-		lineage.Add(gitdomain.NewLocalBranchName("feature-branch"), gitdomain.NewLocalBranchName("main"))
-		config := configdomain.ValidatedConfig{
-			MainBranch: gitdomain.NewLocalBranchName("main"),
-			UnvalidatedConfig: &configdomain.UnvalidatedConfig{
-				Lineage:           lineage,
-				PerennialBranches: gitdomain.NewLocalBranchNames(),
-				PushHook:          false,
+		lineage.Add("feature-branch", "main")
+		config := config.ValidatedConfig{
+			ValidatedConfigData: configdomain.ValidatedConfigData{
+				MainBranch: "main",
+			},
+			NormalConfig: config.NormalConfig{
+				NormalConfigData: configdomain.NormalConfigData{
+					Lineage:           lineage,
+					PerennialBranches: gitdomain.LocalBranchNames{},
+					PushHook:          false,
+				},
 			},
 		}
 		haveProgram := haveChanges.UndoProgram(undobranches.BranchChangesUndoProgramArgs{
 			BeginBranch:              before.Active.GetOrPanic(),
 			Config:                   config,
 			EndBranch:                after.Active.GetOrPanic(),
-			UndoablePerennialCommits: []gitdomain.SHA(nil),
+			UndoablePerennialCommits: []gitdomain.SHA{},
 		})
 		wantProgram := program.Program{
 			// No changes should happen here since all changes were syncs on perennial branches.
