@@ -1,6 +1,7 @@
 package undoconfig
 
 import (
+	"github.com/git-town/git-town/v16/internal/config/configdomain"
 	"github.com/git-town/git-town/v16/internal/vm/opcodes"
 	"github.com/git-town/git-town/v16/internal/vm/program"
 )
@@ -21,32 +22,42 @@ func NewConfigDiffs(before, after ConfigSnapshot) ConfigDiffs {
 func (self ConfigDiffs) UndoProgram() program.Program {
 	result := program.Program{}
 	for _, key := range self.Global.Added {
-		result.Add(&opcodes.RemoveGlobalConfig{Key: key})
+		result.Add(&opcodes.ConfigRemove{
+			Key:   key,
+			Scope: configdomain.ConfigScopeGlobal,
+		})
 	}
 	for key, value := range self.Global.Removed {
-		result.Add(&opcodes.SetGlobalConfig{
+		result.Add(&opcodes.ConfigSet{
 			Key:   key,
+			Scope: configdomain.ConfigScopeGlobal,
 			Value: value,
 		})
 	}
 	for key, change := range self.Global.Changed {
-		result.Add(&opcodes.SetGlobalConfig{
+		result.Add(&opcodes.ConfigSet{
 			Key:   key,
+			Scope: configdomain.ConfigScopeGlobal,
 			Value: change.Before,
 		})
 	}
 	for _, key := range self.Local.Added {
-		result.Add(&opcodes.RemoveLocalConfig{Key: key})
+		result.Add(&opcodes.ConfigRemove{
+			Key:   key,
+			Scope: configdomain.ConfigScopeLocal,
+		})
 	}
 	for key, value := range self.Local.Removed {
-		result.Add(&opcodes.SetLocalConfig{
+		result.Add(&opcodes.ConfigSet{
 			Key:   key,
+			Scope: configdomain.ConfigScopeLocal,
 			Value: value,
 		})
 	}
 	for key, change := range self.Local.Changed {
-		result.Add(&opcodes.SetLocalConfig{
+		result.Add(&opcodes.ConfigSet{
 			Key:   key,
+			Scope: configdomain.ConfigScopeLocal,
 			Value: change.Before,
 		})
 	}
