@@ -12,5 +12,5 @@ type PushCurrentBranch struct {
 }
 
 func (self *PushCurrentBranch) Run(args shared.RunArgs) error {
-	return args.Git.PushCurrentBranch(args.Frontend, args.Config.Config.NoPushHook())
+	return args.Git.PushCurrentBranch(args.Frontend, args.Config.Value.NormalConfig.NoPushHook())
 }
