@@ -14,16 +14,16 @@ type RebaseBranch struct {
 
 func (self *RebaseBranch) AbortProgram() []shared.Opcode {
 	return []shared.Opcode{
-		&AbortRebase{},
+		&RebaseAbort{},
 	}
 }
 
 func (self *RebaseBranch) ContinueProgram() []shared.Opcode {
 	return []shared.Opcode{
-		&ContinueRebaseIfNeeded{},
+		&RebaseContinueIfNeeded{},
 	}
 }
 
 func (self *RebaseBranch) Run(args shared.RunArgs) error {
-	return args.Git.Rebase(args.Frontend, self.Branch, args.Config.GitVersion)
+	return args.Git.Rebase(args.Frontend, self.Branch, args.Config.Value.NormalConfig.GitVersion)
 }
