@@ -18,7 +18,7 @@ func (self *RebaseParentIfNeeded) Run(args shared.RunArgs) error {
 		panic(messages.BranchInfosNotProvided)
 	}
 	for branch := self.Branch; ; {
-		parent, hasParent := args.Config.Config.Lineage.Parent(branch).Get()
+		parent, hasParent := args.Config.Value.NormalConfig.Lineage.Parent(branch).Get()
 		if !hasParent {
 			break
 		}
