@@ -22,14 +22,14 @@ func TestRunState(t *testing.T) {
 			Command: "sync",
 			DryRun:  true,
 			AbortProgram: program.Program{
-				&opcodes.ResetCurrentBranchToSHAIfNeeded{
+				&opcodes.BranchCurrentResetToSHAIfNeeded{
 					MustHaveSHA: gitdomain.NewSHA("222222"),
 					SetToSHA:    gitdomain.NewSHA("111111"),
 					Hard:        false,
 				},
 			},
 			RunProgram: program.Program{
-				&opcodes.ResetCurrentBranchToSHAIfNeeded{
+				&opcodes.BranchCurrentResetToSHAIfNeeded{
 					MustHaveSHA: gitdomain.NewSHA("222222"),
 					SetToSHA:    gitdomain.NewSHA("111111"),
 					Hard:        false,
@@ -59,7 +59,7 @@ func TestRunState(t *testing.T) {
 			BeginBranchesSnapshot:    gitdomain.EmptyBranchesSnapshot(),
 			BeginConfigSnapshot:      undoconfig.EmptyConfigSnapshot(),
 			BeginStashSize:           0,
-			UndoablePerennialCommits: []gitdomain.SHA(nil),
+			UndoablePerennialCommits: []gitdomain.SHA{},
 			TouchedBranches:          []gitdomain.BranchName{"branch-1", "branch-2"},
 		}
 		encoded, err := json.MarshalIndent(runState, "", "  ")
@@ -73,7 +73,7 @@ func TestRunState(t *testing.T) {
         "MustHaveSHA": "222222",
         "SetToSHA": "111111"
       },
-      "type": "ResetCurrentBranchToSHAIfNeeded"
+      "type": "BranchCurrentResetToSHAIfNeeded"
     }
   ],
   "BeginBranchesSnapshot": {
@@ -116,7 +116,7 @@ func TestRunState(t *testing.T) {
         "MustHaveSHA": "222222",
         "SetToSHA": "111111"
       },
-      "type": "ResetCurrentBranchToSHAIfNeeded"
+      "type": "BranchCurrentResetToSHAIfNeeded"
     }
   ],
   "TouchedBranches": [
@@ -124,7 +124,7 @@ func TestRunState(t *testing.T) {
     "branch-2"
   ],
   "UndoAPIProgram": [],
-  "UndoablePerennialCommits": null,
+  "UndoablePerennialCommits": [],
   "UnfinishedDetails": null
 }`[1:]
 		must.EqOp(t, want, string(encoded))
