@@ -5,23 +5,30 @@ package shared
 // and provide opcodes to continue and abort them.
 // Undoing an opcode is done via the undo package.
 type Opcode interface {
-	// CreateAbortProgram provides the opcodes to abort this Opcode when it encounters an error.
-	CreateAbortProgram() []Opcode
+	// AbortProgram provides the opcodes to abort this Opcode when it encounters an error.
+	AbortProgram() []Opcode
 
-	// CreateContinueProgram provides the opcodes continue this opcode
+	// ContinueProgram provides the opcodes continue this opcode
 	// after it encountered an error and the user has resolved the error.
-	CreateContinueProgram() []Opcode
+	ContinueProgram() []Opcode
 
-	// CreateAutomaticUndoError provides the error message to display when this opcode
+	// AutomaticUndoError provides the error message to display when this opcode
 	// cause the command to automatically undo.
-	CreateAutomaticUndoError() error
+	AutomaticUndoError() error
 
 	// Run executes this opcodes.
 	Run(args RunArgs) error
 
-	// ShouldAutomaticallyUndoOnError indicates whether this opcode should
+	// ShouldUndoOnError indicates whether this opcode should
 	// cause the command to automatically undo if it errors.
 	// When true, automatically runs the abort and undo logic and leaves the user where they started.
 	// When false, stops execution to let the user fix the issue and continue or manually undo.
-	ShouldAutomaticallyUndoOnError() bool
+	ShouldUndoOnError() bool
+
+	// UndoProgram provides the opcodes to undo this operation.
+	// All Git changes are automatically undone by the snapshot-based undo engine
+	// and don't need to be undone here.
+	// The undo program returned here is only for external changes
+	// like updating proposals at the code hosting platform.
+	UndoExternalChangesProgram() []Opcode
 }
