@@ -13,7 +13,7 @@ import (
 type RunArgs struct {
 	Backend                         gitdomain.RunnerQuerier
 	BranchInfos                     Option[gitdomain.BranchInfos]
-	Config                          config.ValidatedConfig
+	Config                          Mutable[config.ValidatedConfig]
 	Connector                       Option[hostingdomain.Connector]
 	DialogTestInputs                components.TestInputs
 	FinalMessages                   stringslice.Collector
@@ -21,5 +21,5 @@ type RunArgs struct {
 	Git                             git.Commands
 	PrependOpcodes                  func(...Opcode)
 	RegisterUndoablePerennialCommit func(gitdomain.SHA)
-	UpdateInitialBranchLocalSHA     func(gitdomain.LocalBranchName, gitdomain.SHA) error
+	UpdateInitialSnapshotLocalSHA   func(gitdomain.LocalBranchName, gitdomain.SHA) error
 }
