@@ -46,173 +46,89 @@ func TestLoadSave(t *testing.T) {
 			EndConfigSnapshot:     None[undoconfig.ConfigSnapshot](),
 			EndStashSize:          Some(gitdomain.StashSize(1)),
 			RunProgram: program.Program{
-				&opcodes.AbortMerge{},
-				&opcodes.AbortRebase{},
-				&opcodes.AddToContributionBranches{Branch: gitdomain.NewLocalBranchName("branch")},
-				&opcodes.AddToObservedBranches{Branch: gitdomain.NewLocalBranchName("branch")},
-				&opcodes.AddToParkedBranches{Branch: gitdomain.NewLocalBranchName("branch")},
-				&opcodes.AddToPerennialBranches{Branch: gitdomain.NewLocalBranchName("branch")},
-				&opcodes.AddToPrototypeBranches{Branch: gitdomain.NewLocalBranchName("branch")},
-				&opcodes.ChangeParent{
-					Branch: gitdomain.NewLocalBranchName("branch"),
-					Parent: gitdomain.NewLocalBranchName("parent"),
-				},
-				&opcodes.Checkout{Branch: gitdomain.NewLocalBranchName("branch")},
-				&opcodes.CheckoutIfNeeded{Branch: gitdomain.NewLocalBranchName("branch")},
-				&opcodes.CheckoutUncached{Branch: gitdomain.NewLocalBranchName("branch")},
-				&opcodes.Commit{
-					AuthorOverride:                 Some(gitdomain.Author("user@acme.com")),
-					FallbackToDefaultCommitMessage: true,
-					Message:                        Some(gitdomain.CommitMessage("my message")),
-				},
-				&opcodes.CommitWithMessage{
-					AuthorOverride: Some(gitdomain.Author("user@acme.com")),
-					Message:        gitdomain.CommitMessage("my message"),
-				},
-				&opcodes.ConnectorMergeProposal{
-					Branch:          gitdomain.NewLocalBranchName("branch"),
-					CommitMessage:   Some(gitdomain.CommitMessage("commit message")),
-					ProposalMessage: "proposal message",
-					ProposalNumber:  123,
-				},
-				&opcodes.ContinueMerge{},
-				&opcodes.ContinueRebase{},
-				&opcodes.ContinueRebaseIfNeeded{},
-				&opcodes.CreateBranch{
-					Branch:        gitdomain.NewLocalBranchName("branch"),
-					StartingPoint: gitdomain.NewSHA("123456").Location(),
-				},
-				&opcodes.CreateProposal{
-					Branch:     gitdomain.NewLocalBranchName("branch"),
-					MainBranch: gitdomain.NewLocalBranchName("main"),
-				},
-				&opcodes.CreateRemoteBranch{
-					Branch: gitdomain.NewLocalBranchName("branch"),
-					SHA:    gitdomain.NewSHA("123456"),
-				},
-				&opcodes.CreateTrackingBranch{
-					Branch: gitdomain.NewLocalBranchName("branch"),
-				},
-				&opcodes.DeleteLocalBranch{Branch: gitdomain.NewLocalBranchName("branch")},
-				&opcodes.DeleteParentBranch{
-					Branch: gitdomain.NewLocalBranchName("branch"),
-				},
-				&opcodes.DeleteTrackingBranch{
-					Branch: gitdomain.NewRemoteBranchName("origin/branch"),
-				},
-				&opcodes.DiscardOpenChanges{},
-				&opcodes.DropStash{},
-				&opcodes.EndOfBranchProgram{},
-				&opcodes.EnsureHasShippableChanges{
-					Branch: gitdomain.NewLocalBranchName("branch"),
-					Parent: gitdomain.NewLocalBranchName("parent"),
-				},
-				&opcodes.FetchUpstream{
-					Branch: gitdomain.NewLocalBranchName("branch"),
-				},
-				&opcodes.ForcePushCurrentBranch{ForceIfIncludes: true},
-				&opcodes.Merge{Branch: gitdomain.NewBranchName("branch")},
-				&opcodes.MergeParent{
-					Parent: gitdomain.NewBranchName("parent"),
-				},
-				&opcodes.MergeParentIfNeeded{
-					Branch: gitdomain.NewLocalBranchName("branch"),
-				},
-				&opcodes.PreserveCheckoutHistory{
-					PreviousBranchCandidates: []Option[gitdomain.LocalBranchName]{Some(gitdomain.NewLocalBranchName("previous"))},
-				},
+				&opcodes.BranchCreate{Branch: "branch", StartingPoint: "123456"},
+				&opcodes.BranchCreateAndCheckoutExistingParent{Ancestors: gitdomain.NewLocalBranchNames("one", "two", "three"), Branch: "branch"},
+				&opcodes.BranchCurrentReset{Base: "branch"},
+				&opcodes.BranchCurrentResetToParent{CurrentBranch: "branch"},
+				&opcodes.BranchCurrentResetToSHA{Hard: true, SetToSHA: "111111"},
+				&opcodes.BranchCurrentResetToSHAIfNeeded{Hard: true, MustHaveSHA: "222222", SetToSHA: "111111"},
+				&opcodes.BranchDeleteIfEmptyAtRuntime{Branch: "branch"},
+				&opcodes.BranchEnsureShippableChanges{Branch: "branch", Parent: "parent"},
+				&opcodes.BranchLocalDelete{Branch: "branch"},
+				&opcodes.BranchLocalRename{NewName: "new", OldName: "old"},
+				&opcodes.BranchParentDelete{Branch: "branch"},
+				&opcodes.BranchRemoteCreate{Branch: "branch", SHA: "123456"},
+				&opcodes.BranchRemoteSetToSHA{Branch: "branch", SetToSHA: "222222"},
+				&opcodes.BranchRemoteSetToSHAIfNeeded{Branch: "branch", MustHaveSHA: "111111", SetToSHA: "222222"},
+				&opcodes.BranchReset{Target: "branch"},
+				&opcodes.BranchTrackingCreate{Branch: "branch"},
+				&opcodes.BranchTrackingDelete{Branch: "origin/branch"},
+				&opcodes.BranchesContributionAdd{Branch: "branch"},
+				&opcodes.BranchesContributionRemove{Branch: "branch"},
+				&opcodes.BranchesObservedAdd{Branch: "branch"},
+				&opcodes.BranchesObservedRemove{Branch: "branch"},
+				&opcodes.BranchesParkedAdd{Branch: "branch"},
+				&opcodes.BranchesParkedRemove{Branch: "branch"},
+				&opcodes.BranchesPerennialAdd{Branch: "branch"},
+				&opcodes.BranchesPerennialRemove{Branch: "branch"},
+				&opcodes.BranchesPrototypeAdd{Branch: "branch"},
+				&opcodes.BranchesPrototypeRemove{Branch: "branch"},
+				&opcodes.ChangesDiscard{},
+				&opcodes.ChangesStage{},
+				&opcodes.Checkout{Branch: "branch"},
+				&opcodes.CheckoutHistoryPreserve{PreviousBranchCandidates: []Option[gitdomain.LocalBranchName]{Some(gitdomain.NewLocalBranchName("previous"))}},
+				&opcodes.CheckoutIfNeeded{Branch: "branch"},
+				&opcodes.CheckoutUncached{Branch: "branch"},
+				&opcodes.Commit{AuthorOverride: Some(gitdomain.Author("user@acme.com")), FallbackToDefaultCommitMessage: true, Message: Some(gitdomain.CommitMessage("my message"))},
+				&opcodes.CommitAutoUndo{AuthorOverride: Some(gitdomain.Author("user@acme.com")), FallbackToDefaultCommitMessage: true, Message: Some(gitdomain.CommitMessage("my message"))},
+				&opcodes.CommitMessageCommentOut{},
+				&opcodes.CommitRevert{SHA: "123456"},
+				&opcodes.CommitRevertIfNeeded{SHA: "123456"},
+				&opcodes.CommitWithMessage{AuthorOverride: Some(gitdomain.Author("user@acme.com")), Message: "my message"},
+				&opcodes.ConfigRemove{Key: configdomain.KeyOffline, Scope: configdomain.ConfigScopeLocal},
+				&opcodes.ConfigSet{Key: configdomain.KeyOffline, Scope: configdomain.ConfigScopeLocal, Value: "1"},
+				&opcodes.ConflictPhantomDetect{ParentBranch: Some(gitdomain.NewLocalBranchName("parent")), ParentSHA: Some(gitdomain.NewSHA("123456"))},
+				&opcodes.ConflictPhantomFinalize{},
+				&opcodes.ConflictPhantomResolve{FilePath: "file"},
+				&opcodes.ConnectorProposalMerge{Branch: "branch", CommitMessage: Some(gitdomain.CommitMessage("commit message")), ProposalMessage: "proposal message", ProposalNumber: 123},
+				&opcodes.FetchUpstream{Branch: "branch"},
+				&opcodes.LineageBranchRemove{Branch: "branch"},
+				&opcodes.LineageParentRemove{Branch: "branch"},
+				&opcodes.LineageParentSet{Branch: "branch", Parent: "parent"},
+				&opcodes.LineageParentSetFirstExisting{Ancestors: gitdomain.NewLocalBranchNames("one", "two"), Branch: "branch"},
+				&opcodes.LineageParentSetIfExists{Branch: "branch", Parent: "parent"},
+				&opcodes.LineageParentSetToGrandParent{Branch: "branch"},
+				&opcodes.Merge{Branch: "branch"},
+				&opcodes.MergeAbort{},
+				&opcodes.MergeContinue{},
+				&opcodes.MergeParent{CurrentParent: "parent", OriginalParentName: Some(gitdomain.NewLocalBranchName("original-parent")), OriginalParentSHA: Some(gitdomain.NewSHA("123456"))},
+				&opcodes.MergeParentIfNeeded{Branch: "branch", OriginalParentName: Some(gitdomain.NewLocalBranchName("original-parent")), OriginalParentSHA: Some(gitdomain.NewSHA("123456"))},
+				&opcodes.MergeSquashProgram{Authors: []gitdomain.Author{"author 1 <one@acme.com>", "author 2 <two@acme.com>"}, Branch: "branch", CommitMessage: Some(gitdomain.CommitMessage("commit message")), Parent: "parent"},
+				&opcodes.MessageQueue{Message: "message"},
+				&opcodes.ProgramEndOfBranch{},
+				&opcodes.ProposalCreate{Branch: "branch", MainBranch: "main"},
+				&opcodes.ProposalUpdateTarget{ProposalNumber: 123, NewBranch: "new-target", OldBranch: "old-target"},
+				&opcodes.ProposalUpdateTargetToParent{Branch: "branch", ProposalNumber: 123, OldTarget: "old-target"},
+				&opcodes.ProposalUpdateSource{ProposalNumber: 123, NewBranch: "new-target", OldBranch: "old-target"},
 				&opcodes.PullCurrentBranch{},
-				&opcodes.PushCurrentBranch{
-					CurrentBranch: gitdomain.NewLocalBranchName("branch"),
-				},
-				&opcodes.PushCurrentBranchIfNeeded{
-					CurrentBranch: gitdomain.NewLocalBranchName("branch"),
-				},
+				&opcodes.PushCurrentBranch{CurrentBranch: "branch"},
+				&opcodes.PushCurrentBranchForceIfNeeded{ForceIfIncludes: true},
+				&opcodes.PushCurrentBranchIfLocal{CurrentBranch: "branch"},
+				&opcodes.PushCurrentBranchIfNeeded{CurrentBranch: "branch"},
 				&opcodes.PushTags{},
-				&opcodes.RebaseBranch{
-					Branch: gitdomain.NewBranchName("branch"),
-				},
-				&opcodes.RebaseParentIfNeeded{
-					Branch: gitdomain.NewLocalBranchName("branch"),
-				},
-				&opcodes.RebaseFeatureTrackingBranch{
-					RemoteBranch: gitdomain.NewRemoteBranchName("origin/branch"),
-				},
-				&opcodes.RemoveFromContributionBranches{
-					Branch: gitdomain.NewLocalBranchName("branch"),
-				},
-				&opcodes.RemoveFromObservedBranches{
-					Branch: gitdomain.NewLocalBranchName("branch"),
-				},
-				&opcodes.RemoveFromParkedBranches{
-					Branch: gitdomain.NewLocalBranchName("branch"),
-				},
-				&opcodes.RemoveFromPerennialBranches{
-					Branch: gitdomain.NewLocalBranchName("branch"),
-				},
-				&opcodes.RemoveFromPrototypeBranches{
-					Branch: gitdomain.NewLocalBranchName("branch"),
-				},
-				&opcodes.RemoveGlobalConfig{
-					Key: configdomain.KeyOffline,
-				},
-				&opcodes.RemoveLocalConfig{
-					Key: configdomain.KeyOffline,
-				},
-				&opcodes.RenameBranch{
-					NewName: "new",
-					OldName: "old",
-				},
-				&opcodes.ResetCurrentBranchToSHA{
-					Hard:     true,
-					SetToSHA: gitdomain.NewSHA("111111"),
-				},
-				&opcodes.ResetCurrentBranchToSHAIfNeeded{
-					Hard:        true,
-					MustHaveSHA: gitdomain.NewSHA("222222"),
-					SetToSHA:    gitdomain.NewSHA("111111"),
-				},
-				&opcodes.RestoreOpenChanges{},
-				&opcodes.RevertCommit{
-					SHA: gitdomain.NewSHA("123456"),
-				},
-				&opcodes.RevertCommitIfNeeded{
-					SHA: gitdomain.NewSHA("123456"),
-				},
-				&opcodes.SetGlobalConfig{
-					Key:   configdomain.KeyOffline,
-					Value: "1",
-				},
-				&opcodes.SetLocalConfig{
-					Key:   configdomain.KeyOffline,
-					Value: "1",
-				},
-				&opcodes.SetParent{
-					Branch: gitdomain.NewLocalBranchName("branch"),
-					Parent: gitdomain.NewLocalBranchName("parent"),
-				},
-				&opcodes.SetParentIfBranchExists{
-					Branch: gitdomain.NewLocalBranchName("branch"),
-					Parent: gitdomain.NewLocalBranchName("parent"),
-				},
-				&opcodes.SkipCurrentBranch{},
-				&opcodes.SquashMerge{
-					Branch:        gitdomain.NewLocalBranchName("branch"),
-					CommitMessage: Some(gitdomain.CommitMessage("commit message")),
-					Parent:        gitdomain.NewLocalBranchName("parent"),
-				},
-				&opcodes.StageOpenChanges{},
+				&opcodes.RebaseAbort{},
+				&opcodes.RebaseBranch{Branch: "branch"},
+				&opcodes.RebaseContinue{},
+				&opcodes.RebaseContinueIfNeeded{},
+				&opcodes.RebaseParentIfNeeded{Branch: "branch"},
+				&opcodes.RebaseTrackingBranch{RemoteBranch: "origin/branch"},
+				&opcodes.RegisterUndoablePerennialCommit{Parent: "parent"},
+				&opcodes.SnapshotInitialUpdateLocalSHA{Branch: "branch", SHA: "111111"},
+				&opcodes.SnapshotInitialUpdateLocalSHAIfNeeded{Branch: "branch"},
+				&opcodes.StashDrop{},
+				&opcodes.StashPop{},
+				&opcodes.StashPopIfNeeded{},
 				&opcodes.StashOpenChanges{},
-				&opcodes.UpdateProposalBase{
-					ProposalNumber: 123,
-					NewTarget:      gitdomain.NewLocalBranchName("new-target"),
-					OldTarget:      gitdomain.NewLocalBranchName("old-target"),
-				},
-				&opcodes.UpdateProposalHead{
-					ProposalNumber: 123,
-					NewTarget:      gitdomain.NewLocalBranchName("new-target"),
-					OldTarget:      gitdomain.NewLocalBranchName("old-target"),
-				},
 			},
 			TouchedBranches: []gitdomain.BranchName{"branch-1", "branch-2"},
 			UnfinishedDetails: SomeP(&runstate.UnfinishedRunStateDetails{
@@ -220,7 +136,7 @@ func TestLoadSave(t *testing.T) {
 				EndBranch: gitdomain.NewLocalBranchName("end-branch"),
 				EndTime:   time.Time{},
 			}),
-			UndoablePerennialCommits: []gitdomain.SHA(nil),
+			UndoablePerennialCommits: []gitdomain.SHA{},
 		}
 
 		wantJSON := `
@@ -243,49 +159,189 @@ func TestLoadSave(t *testing.T) {
   "FinalUndoProgram": [],
   "RunProgram": [
     {
-      "data": {},
-      "type": "AbortMerge"
+      "data": {
+        "Branch": "branch",
+        "StartingPoint": "123456"
+      },
+      "type": "BranchCreate"
     },
     {
-      "data": {},
-      "type": "AbortRebase"
+      "data": {
+        "Ancestors": [
+          "one",
+          "two",
+          "three"
+        ],
+        "Branch": "branch"
+      },
+      "type": "BranchCreateAndCheckoutExistingParent"
+    },
+    {
+      "data": {
+        "Base": "branch"
+      },
+      "type": "BranchCurrentReset"
+    },
+    {
+      "data": {
+        "CurrentBranch": "branch"
+      },
+      "type": "BranchCurrentResetToParent"
+    },
+    {
+      "data": {
+        "Hard": true,
+        "SetToSHA": "111111"
+      },
+      "type": "BranchCurrentResetToSHA"
+    },
+    {
+      "data": {
+        "Hard": true,
+        "MustHaveSHA": "222222",
+        "SetToSHA": "111111"
+      },
+      "type": "BranchCurrentResetToSHAIfNeeded"
     },
     {
       "data": {
         "Branch": "branch"
       },
-      "type": "AddToContributionBranches"
-    },
-    {
-      "data": {
-        "Branch": "branch"
-      },
-      "type": "AddToObservedBranches"
-    },
-    {
-      "data": {
-        "Branch": "branch"
-      },
-      "type": "AddToParkedBranches"
-    },
-    {
-      "data": {
-        "Branch": "branch"
-      },
-      "type": "AddToPerennialBranches"
-    },
-    {
-      "data": {
-        "Branch": "branch"
-      },
-      "type": "AddToPrototypeBranches"
+      "type": "BranchDeleteIfEmptyAtRuntime"
     },
     {
       "data": {
         "Branch": "branch",
         "Parent": "parent"
       },
-      "type": "ChangeParent"
+      "type": "BranchEnsureShippableChanges"
+    },
+    {
+      "data": {
+        "Branch": "branch"
+      },
+      "type": "BranchLocalDelete"
+    },
+    {
+      "data": {
+        "NewName": "new",
+        "OldName": "old"
+      },
+      "type": "BranchLocalRename"
+    },
+    {
+      "data": {
+        "Branch": "branch"
+      },
+      "type": "BranchParentDelete"
+    },
+    {
+      "data": {
+        "Branch": "branch",
+        "SHA": "123456"
+      },
+      "type": "BranchRemoteCreate"
+    },
+    {
+      "data": {
+        "Branch": "branch",
+        "SetToSHA": "222222"
+      },
+      "type": "BranchRemoteSetToSHA"
+    },
+    {
+      "data": {
+        "Branch": "branch",
+        "MustHaveSHA": "111111",
+        "SetToSHA": "222222"
+      },
+      "type": "BranchRemoteSetToSHAIfNeeded"
+    },
+    {
+      "data": {
+        "Target": "branch"
+      },
+      "type": "BranchReset"
+    },
+    {
+      "data": {
+        "Branch": "branch"
+      },
+      "type": "BranchTrackingCreate"
+    },
+    {
+      "data": {
+        "Branch": "origin/branch"
+      },
+      "type": "BranchTrackingDelete"
+    },
+    {
+      "data": {
+        "Branch": "branch"
+      },
+      "type": "BranchesContributionAdd"
+    },
+    {
+      "data": {
+        "Branch": "branch"
+      },
+      "type": "BranchesContributionRemove"
+    },
+    {
+      "data": {
+        "Branch": "branch"
+      },
+      "type": "BranchesObservedAdd"
+    },
+    {
+      "data": {
+        "Branch": "branch"
+      },
+      "type": "BranchesObservedRemove"
+    },
+    {
+      "data": {
+        "Branch": "branch"
+      },
+      "type": "BranchesParkedAdd"
+    },
+    {
+      "data": {
+        "Branch": "branch"
+      },
+      "type": "BranchesParkedRemove"
+    },
+    {
+      "data": {
+        "Branch": "branch"
+      },
+      "type": "BranchesPerennialAdd"
+    },
+    {
+      "data": {
+        "Branch": "branch"
+      },
+      "type": "BranchesPerennialRemove"
+    },
+    {
+      "data": {
+        "Branch": "branch"
+      },
+      "type": "BranchesPrototypeAdd"
+    },
+    {
+      "data": {
+        "Branch": "branch"
+      },
+      "type": "BranchesPrototypeRemove"
+    },
+    {
+      "data": {},
+      "type": "ChangesDiscard"
+    },
+    {
+      "data": {},
+      "type": "ChangesStage"
     },
     {
       "data": {
@@ -293,6 +349,14 @@ func TestLoadSave(t *testing.T) {
       },
       "type": "Checkout"
     },
+    {
+      "data": {
+        "PreviousBranchCandidates": [
+          "previous"
+        ]
+      },
+      "type": "CheckoutHistoryPreserve"
+    },
     {
       "data": {
         "Branch": "branch"
@@ -313,6 +377,30 @@ func TestLoadSave(t *testing.T) {
       },
       "type": "Commit"
     },
+    {
+      "data": {
+        "AuthorOverride": "user@acme.com",
+        "FallbackToDefaultCommitMessage": true,
+        "Message": "my message"
+      },
+      "type": "CommitAutoUndo"
+    },
+    {
+      "data": {},
+      "type": "CommitMessageCommentOut"
+    },
+    {
+      "data": {
+        "SHA": "123456"
+      },
+      "type": "CommitRevert"
+    },
+    {
+      "data": {
+        "SHA": "123456"
+      },
+      "type": "CommitRevertIfNeeded"
+    },
     {
       "data": {
         "AuthorOverride": "user@acme.com",
@@ -320,6 +408,38 @@ func TestLoadSave(t *testing.T) {
       },
       "type": "CommitWithMessage"
     },
+    {
+      "data": {
+        "Key": "git-town.offline",
+        "Scope": "local"
+      },
+      "type": "ConfigRemove"
+    },
+    {
+      "data": {
+        "Key": "git-town.offline",
+        "Scope": "local",
+        "Value": "1"
+      },
+      "type": "ConfigSet"
+    },
+    {
+      "data": {
+        "ParentBranch": "parent",
+        "ParentSHA": "123456"
+      },
+      "type": "ConflictPhantomDetect"
+    },
+    {
+      "data": {},
+      "type": "ConflictPhantomFinalize"
+    },
+    {
+      "data": {
+        "FilePath": "file"
+      },
+      "type": "ConflictPhantomResolve"
+    },
     {
       "data": {
         "Branch": "branch",
@@ -327,85 +447,7 @@ func TestLoadSave(t *testing.T) {
         "ProposalMessage": "proposal message",
         "ProposalNumber": 123
       },
-      "type": "ConnectorMergeProposal"
-    },
-    {
-      "data": {},
-      "type": "ContinueMerge"
-    },
-    {
-      "data": {},
-      "type": "ContinueRebase"
-    },
-    {
-      "data": {},
-      "type": "ContinueRebaseIfNeeded"
-    },
-    {
-      "data": {
-        "Branch": "branch",
-        "StartingPoint": "123456"
-      },
-      "type": "CreateBranch"
-    },
-    {
-      "data": {
-        "Branch": "branch",
-        "MainBranch": "main",
-        "ProposalBody": "",
-        "ProposalTitle": ""
-      },
-      "type": "CreateProposal"
-    },
-    {
-      "data": {
-        "Branch": "branch",
-        "SHA": "123456"
-      },
-      "type": "CreateRemoteBranch"
-    },
-    {
-      "data": {
-        "Branch": "branch"
-      },
-      "type": "CreateTrackingBranch"
-    },
-    {
-      "data": {
-        "Branch": "branch"
-      },
-      "type": "DeleteLocalBranch"
-    },
-    {
-      "data": {
-        "Branch": "branch"
-      },
-      "type": "DeleteParentBranch"
-    },
-    {
-      "data": {
-        "Branch": "origin/branch"
-      },
-      "type": "DeleteTrackingBranch"
-    },
-    {
-      "data": {},
-      "type": "DiscardOpenChanges"
-    },
-    {
-      "data": {},
-      "type": "DropStash"
-    },
-    {
-      "data": {},
-      "type": "EndOfBranchProgram"
-    },
-    {
-      "data": {
-        "Branch": "branch",
-        "Parent": "parent"
-      },
-      "type": "EnsureHasShippableChanges"
+      "type": "ConnectorProposalMerge"
     },
     {
       "data": {
@@ -415,9 +457,45 @@ func TestLoadSave(t *testing.T) {
     },
     {
       "data": {
-        "ForceIfIncludes": true
+        "Branch": "branch"
       },
-      "type": "ForcePushCurrentBranch"
+      "type": "LineageBranchRemove"
+    },
+    {
+      "data": {
+        "Branch": "branch"
+      },
+      "type": "LineageParentRemove"
+    },
+    {
+      "data": {
+        "Branch": "branch",
+        "Parent": "parent"
+      },
+      "type": "LineageParentSet"
+    },
+    {
+      "data": {
+        "Ancestors": [
+          "one",
+          "two"
+        ],
+        "Branch": "branch"
+      },
+      "type": "LineageParentSetFirstExisting"
+    },
+    {
+      "data": {
+        "Branch": "branch",
+        "Parent": "parent"
+      },
+      "type": "LineageParentSetIfExists"
+    },
+    {
+      "data": {
+        "Branch": "branch"
+      },
+      "type": "LineageParentSetToGrandParent"
     },
     {
       "data": {
@@ -425,25 +503,84 @@ func TestLoadSave(t *testing.T) {
       },
       "type": "Merge"
     },
+    {
+      "data": {},
+      "type": "MergeAbort"
+    },
+    {
+      "data": {},
+      "type": "MergeContinue"
+    },
     {
       "data": {
-        "Parent": "parent"
+        "CurrentParent": "parent",
+        "OriginalParentName": "original-parent",
+        "OriginalParentSHA": "123456"
       },
       "type": "MergeParent"
     },
     {
       "data": {
-        "Branch": "branch"
+        "Branch": "branch",
+        "OriginalParentName": "original-parent",
+        "OriginalParentSHA": "123456"
       },
       "type": "MergeParentIfNeeded"
     },
     {
       "data": {
-        "PreviousBranchCandidates": [
-          "previous"
-        ]
+        "Authors": [
+          "author 1 \u003cone@acme.com\u003e",
+          "author 2 \u003ctwo@acme.com\u003e"
+        ],
+        "Branch": "branch",
+        "CommitMessage": "commit message",
+        "Parent": "parent"
       },
-      "type": "PreserveCheckoutHistory"
+      "type": "MergeSquashProgram"
+    },
+    {
+      "data": {
+        "Message": "message"
+      },
+      "type": "MessageQueue"
+    },
+    {
+      "data": {},
+      "type": "ProgramEndOfBranch"
+    },
+    {
+      "data": {
+        "Branch": "branch",
+        "MainBranch": "main",
+        "ProposalBody": "",
+        "ProposalTitle": ""
+      },
+      "type": "ProposalCreate"
+    },
+    {
+      "data": {
+        "NewBranch": "new-target",
+        "OldBranch": "old-target",
+        "ProposalNumber": 123
+      },
+      "type": "ProposalUpdateTarget"
+    },
+    {
+      "data": {
+        "Branch": "branch",
+        "OldTarget": "old-target",
+        "ProposalNumber": 123
+      },
+      "type": "ProposalUpdateTargetToParent"
+    },
+    {
+      "data": {
+        "NewBranch": "new-target",
+        "OldBranch": "old-target",
+        "ProposalNumber": 123
+      },
+      "type": "ProposalUpdateSource"
     },
     {
       "data": {},
@@ -455,6 +592,18 @@ func TestLoadSave(t *testing.T) {
       },
       "type": "PushCurrentBranch"
     },
+    {
+      "data": {
+        "ForceIfIncludes": true
+      },
+      "type": "PushCurrentBranchForceIfNeeded"
+    },
+    {
+      "data": {
+        "CurrentBranch": "branch"
+      },
+      "type": "PushCurrentBranchIfLocal"
+    },
     {
       "data": {
         "CurrentBranch": "branch"
@@ -465,12 +614,24 @@ func TestLoadSave(t *testing.T) {
       "data": {},
       "type": "PushTags"
     },
+    {
+      "data": {},
+      "type": "RebaseAbort"
+    },
     {
       "data": {
         "Branch": "branch"
       },
       "type": "RebaseBranch"
     },
+    {
+      "data": {},
+      "type": "RebaseContinue"
+    },
+    {
+      "data": {},
+      "type": "RebaseContinueIfNeeded"
+    },
     {
       "data": {
         "Branch": "branch"
@@ -482,151 +643,42 @@ func TestLoadSave(t *testing.T) {
         "PushBranches": false,
         "RemoteBranch": "origin/branch"
       },
-      "type": "RebaseFeatureTrackingBranch"
+      "type": "RebaseTrackingBranch"
     },
     {
       "data": {
-        "Branch": "branch"
+        "Parent": "parent"
       },
-      "type": "RemoveFromContributionBranches"
-    },
-    {
-      "data": {
-        "Branch": "branch"
-      },
-      "type": "RemoveFromObservedBranches"
-    },
-    {
-      "data": {
-        "Branch": "branch"
-      },
-      "type": "RemoveFromParkedBranches"
-    },
-    {
-      "data": {
-        "Branch": "branch"
-      },
-      "type": "RemoveFromPerennialBranches"
-    },
-    {
-      "data": {
-        "Branch": "branch"
-      },
-      "type": "RemoveFromPrototypeBranches"
-    },
-    {
-      "data": {
-        "Key": "git-town.offline"
-      },
-      "type": "RemoveGlobalConfig"
-    },
-    {
-      "data": {
-        "Key": "git-town.offline"
-      },
-      "type": "RemoveLocalConfig"
-    },
-    {
-      "data": {
-        "NewName": "new",
-        "OldName": "old"
-      },
-      "type": "RenameBranch"
-    },
-    {
-      "data": {
-        "Hard": true,
-        "SetToSHA": "111111"
-      },
-      "type": "ResetCurrentBranchToSHA"
-    },
-    {
-      "data": {
-        "Hard": true,
-        "MustHaveSHA": "222222",
-        "SetToSHA": "111111"
-      },
-      "type": "ResetCurrentBranchToSHAIfNeeded"
-    },
-    {
-      "data": {},
-      "type": "RestoreOpenChanges"
-    },
-    {
-      "data": {
-        "SHA": "123456"
-      },
-      "type": "RevertCommit"
-    },
-    {
-      "data": {
-        "SHA": "123456"
-      },
-      "type": "RevertCommitIfNeeded"
-    },
-    {
-      "data": {
-        "Key": "git-town.offline",
-        "Value": "1"
-      },
-      "type": "SetGlobalConfig"
-    },
-    {
-      "data": {
-        "Key": "git-town.offline",
-        "Value": "1"
-      },
-      "type": "SetLocalConfig"
+      "type": "RegisterUndoablePerennialCommit"
     },
     {
       "data": {
         "Branch": "branch",
-        "Parent": "parent"
+        "SHA": "111111"
       },
-      "type": "SetParent"
+      "type": "SnapshotInitialUpdateLocalSHA"
     },
     {
       "data": {
-        "Branch": "branch",
-        "Parent": "parent"
+        "Branch": "branch"
       },
-      "type": "SetParentIfBranchExists"
+      "type": "SnapshotInitialUpdateLocalSHAIfNeeded"
     },
     {
       "data": {},
-      "type": "SkipCurrentBranch"
-    },
-    {
-      "data": {
-        "Branch": "branch",
-        "CommitMessage": "commit message",
-        "Parent": "parent"
-      },
-      "type": "SquashMerge"
+      "type": "StashDrop"
     },
     {
       "data": {},
-      "type": "StageOpenChanges"
+      "type": "StashPop"
+    },
+    {
+      "data": {},
+      "type": "StashPopIfNeeded"
     },
     {
       "data": {},
       "type": "StashOpenChanges"
-    },
-    {
-      "data": {
-        "NewTarget": "new-target",
-        "OldTarget": "old-target",
-        "ProposalNumber": 123
-      },
-      "type": "UpdateProposalBase"
-    },
-    {
-      "data": {
-        "NewTarget": "new-target",
-        "OldTarget": "old-target",
-        "ProposalNumber": 123
-      },
-      "type": "UpdateProposalHead"
     }
   ],
   "TouchedBranches": [
@@ -634,7 +686,7 @@ func TestLoadSave(t *testing.T) {
     "branch-2"
   ],
   "UndoAPIProgram": [],
-  "UndoablePerennialCommits": null,
+  "UndoablePerennialCommits": [],
   "UnfinishedDetails": {
     "CanSkip": true,
     "EndBranch": "end-branch",
