@@ -26,7 +26,7 @@ const ConfigFileCommitMessage = "persisted config file"
 type TestCommands struct {
 	*subshell.TestRunner
 	*prodgit.Commands
-	Config config.ValidatedConfig
+	Config config.UnvalidatedConfig
 }
 
 // AddRemote adds a Git remote with the given name and URL to this repository.
@@ -68,7 +68,10 @@ func (self *TestCommands) CommitStagedChanges(message gitdomain.CommitMessage) {
 }
 
 // Commits provides a list of the commits in this Git repository with the given fields.
-func (self *TestCommands) Commits(fields []string, mainBranch gitdomain.LocalBranchName) []git.Commit {
+func (self *TestCommands) Commits(fields []string, mainBranch gitdomain.LocalBranchName, lineage configdomain.Lineage) []git.Commit {
+	// NOTE: This method uses the provided lineage instead of self.Config.NormalConfig.Lineage
+	//       because it might determine the commits on a remote repo, and that repo has no lineage information.
+	//       We therefore always provide the lineage of the local repo.
 	branches, err := self.LocalBranchesMainFirst(mainBranch)
 	asserts.NoError(err)
 	var result []git.Commit
@@ -76,18 +79,28 @@ func (self *TestCommands) Commits(fields []string, mainBranch gitdomain.LocalBra
 		if strings.HasPrefix(branch.String(), "+ ") {
 			continue
 		}
-		commits := self.CommitsInBranch(branch, fields)
+		parent := self.ExistingParent(branch, lineage)
+		commits := self.CommitsInBranch(branch, parent, fields)
 		result = append(result, commits...)
 	}
 	return result
 }
 
 // CommitsInBranch provides all commits in the given Git branch.
-func (self *TestCommands) CommitsInBranch(branch gitdomain.LocalBranchName, fields []string) []git.Commit {
-	output := self.MustQuery("git", "log", branch.String(), "--format=%h|%s|%an <%ae>", "--topo-order", "--reverse")
+func (self *TestCommands) CommitsInBranch(branch gitdomain.LocalBranchName, parentOpt Option[gitdomain.LocalBranchName], fields []string) []git.Commit {
+	args := []string{"log", "--format=%h|%s|%an <%ae>", "--topo-order", "--reverse"}
+	if parent, hasParent := parentOpt.Get(); hasParent {
+		args = append(args, fmt.Sprintf("%s..%s", parent, branch))
+	} else {
+		args = append(args, branch.String())
+	}
+	output := self.MustQuery("git", args...)
 	lines := strings.Split(output, "\n")
 	result := make([]git.Commit, 0, len(lines))
 	for _, line := range lines {
+		if len(strings.TrimSpace(line)) == 0 {
+			continue
+		}
 		parts := strings.Split(line, "|")
 		commit := git.Commit{Branch: branch, SHA: gitdomain.NewSHA(parts[0]), Message: gitdomain.CommitMessage(parts[1]), Author: gitdomain.Author(parts[2])}
 		if strings.EqualFold(commit.Message.String(), "initial commit") || strings.EqualFold(commit.Message.String(), ConfigFileCommitMessage) {
@@ -112,6 +125,13 @@ func (self *TestCommands) ConnectTrackingBranch(name gitdomain.LocalBranchName)
 	self.MustRun("git", "branch", "--set-upstream-to=origin/"+name.String(), name.String())
 }
 
+// creates a feature branch with the given name in this repository
+func (self *TestCommands) CreateAndCheckoutFeatureBranch(name gitdomain.LocalBranchName, parent gitdomain.Location) {
+	err := self.CreateAndCheckoutBranchWithParent(self, name, parent)
+	asserts.NoError(err)
+	self.MustRun("git", "config", "git-town-branch."+name.String()+".parent", parent.String())
+}
+
 // CreateBranch creates a new branch with the given name.
 // The created branch is a normal branch.
 // To create feature branches, use CreateFeatureBranch.
@@ -123,7 +143,7 @@ func (self *TestCommands) CreateBranch(name gitdomain.LocalBranchName, parent gi
 // The parent branch must already exist.
 func (self *TestCommands) CreateChildFeatureBranch(branch gitdomain.LocalBranchName, parent gitdomain.LocalBranchName) {
 	self.CreateBranch(branch, parent.BranchName())
-	asserts.NoError(self.Config.SetParent(branch, parent))
+	asserts.NoError(self.Config.NormalConfig.SetParent(branch, parent))
 }
 
 // CreateCommit creates a commit with the given properties in this Git repo.
@@ -141,7 +161,7 @@ func (self *TestCommands) CreateCommit(commit git.Commit) {
 // creates a contribution branches with the given name in this repository
 func (self *TestCommands) CreateContributionBranch(name gitdomain.LocalBranchName) {
 	self.CreateBranch(name, "main")
-	asserts.NoError(self.Config.AddToContributionBranches(name))
+	asserts.NoError(self.Config.NormalConfig.AddToContributionBranches(name))
 }
 
 // creates a feature branch with the given name in this repository
@@ -168,25 +188,25 @@ func (self *TestCommands) CreateFolder(name string) {
 // creates an observed branch with the given name in this repository
 func (self *TestCommands) CreateObservedBranch(name gitdomain.LocalBranchName) {
 	self.CreateBranch(name, "main")
-	asserts.NoError(self.Config.AddToObservedBranches(name))
+	asserts.NoError(self.Config.NormalConfig.AddToObservedBranches(name))
 }
 
 // creates a parked branch with the given name and parent in this repository
 func (self *TestCommands) CreateParkedBranch(name, parent gitdomain.LocalBranchName) {
 	self.CreateFeatureBranch(name, parent.BranchName())
-	asserts.NoError(self.Config.AddToParkedBranches(name))
+	asserts.NoError(self.Config.NormalConfig.AddToParkedBranches(name))
 }
 
 // creates a perennial branch with the given name in this repository
 func (self *TestCommands) CreatePerennialBranch(name gitdomain.LocalBranchName) {
 	self.CreateBranch(name, "main")
-	asserts.NoError(self.Config.AddToPerennialBranches(name))
+	asserts.NoError(self.Config.NormalConfig.AddToPerennialBranches(name))
 }
 
 // creates a prototype branch with the given name and parent in this repository
 func (self *TestCommands) CreatePrototypeBranch(name, parent gitdomain.LocalBranchName) {
 	self.CreateFeatureBranch(name, parent.BranchName())
-	asserts.NoError(self.Config.AddToPrototypeBranches(name))
+	asserts.NoError(self.Config.NormalConfig.AddToPrototypeBranches(name))
 }
 
 // CreateStandaloneTag creates a tag not on a branch.
@@ -209,6 +229,21 @@ func (self *TestCommands) CurrentCommitMessage() string {
 	return self.MustQuery("git", "log", "-1", "--pretty=%B")
 }
 
+// provides the first ancestor of the given branch that actually exists in the repo
+func (self *TestCommands) ExistingParent(branch gitdomain.LocalBranchName, lineage configdomain.Lineage) Option[gitdomain.LocalBranchName] {
+	for {
+		parentOpt := lineage.Parent(branch)
+		parent, hasParent := parentOpt.Get()
+		if !hasParent {
+			return None[gitdomain.LocalBranchName]()
+		}
+		if self.BranchExists(self, parent) {
+			return Some(parent)
+		}
+		branch = parent
+	}
+}
+
 // Fetch retrieves the updates from the origin repo.
 func (self *TestCommands) Fetch() {
 	self.MustRun("git", "fetch")
@@ -274,12 +309,20 @@ func (self *TestCommands) FilesInBranches(mainBranch gitdomain.LocalBranchName)
 
 // FilesInCommit provides the names of the files that the commit with the given SHA changes.
 func (self *TestCommands) FilesInCommit(sha gitdomain.SHA) []string {
-	output := self.MustQuery("git", "diff-tree", "--no-commit-id", "--name-only", "-r", sha.String())
+	output := self.MustQuery("git", "show", "--name-only", "--pretty=format:", sha.String())
 	return strings.Split(output, "\n")
 }
 
-func (self *TestCommands) GlobalGitConfig(name configdomain.Key) Option[string] {
-	output, err := self.Query("git", "config", "--global", "--get", name.String())
+func (self *TestCommands) GitConfig(scope configdomain.ConfigScope, name configdomain.Key) Option[string] {
+	args := []string{"config"}
+	switch scope {
+	case configdomain.ConfigScopeGlobal:
+		args = append(args, "--global")
+	case configdomain.ConfigScopeLocal:
+		args = append(args, "--local")
+	}
+	args = append(args, "--get", name.String())
+	output, err := self.Query("git", args...)
 	if err != nil {
 		return None[string]()
 	}
@@ -310,7 +353,7 @@ func (self *TestCommands) HasFile(name, content string) string {
 func (self *TestCommands) LineageTable() datatable.DataTable {
 	result := datatable.DataTable{}
 	result.AddRow("BRANCH", "PARENT")
-	_, localGitConfig, _ := self.Config.GitConfig.LoadLocal(false) // we ignore the Git cache here because reloading a config in the middle of a Git Town command doesn't change the cached initial state of the repo
+	_, localGitConfig, _ := self.Config.NormalConfig.GitConfig.LoadLocal(false) // we ignore the Git cache here because reloading a config in the middle of a Git Town command doesn't change the cached initial state of the repo
 	lineage := localGitConfig.Lineage
 	for _, branchName := range lineage.BranchNames() {
 		result.AddRow(branchName.String(), lineage.Parent(branchName).String())
@@ -319,6 +362,11 @@ func (self *TestCommands) LineageTable() datatable.DataTable {
 	return result
 }
 
+// SetGitAlias sets the Git alias with the given name to the given value.
+func (self *TestCommands) LoadGitAlias(name configdomain.AliasableCommand) (string, error) {
+	return self.Query("git", "config", "--get", "--global", configdomain.AliasKeyPrefix+name.String())
+}
+
 // LocalBranches provides the names of all branches in the local repository,
 // ordered alphabetically.
 func (self *TestCommands) LocalBranches() (gitdomain.LocalBranchNames, error) {
@@ -345,14 +393,6 @@ func (self *TestCommands) LocalBranchesMainFirst(mainBranch gitdomain.LocalBranc
 	return branches, nil
 }
 
-func (self *TestCommands) LocalGitConfig(name configdomain.Key) Option[string] {
-	output, err := self.Query("git", "config", "--local", "--get", name.String())
-	if err != nil {
-		return None[string]()
-	}
-	return Some(output)
-}
-
 func (self *TestCommands) MergeBranch(branch gitdomain.LocalBranchName) error {
 	return self.Run("git", "merge", branch.String())
 }
@@ -381,7 +421,7 @@ func (self *TestCommands) RemoveMainBranchConfiguration() {
 
 // RemovePerennialBranchConfiguration removes the configuration entry for the perennial branches.
 func (self *TestCommands) RemovePerennialBranchConfiguration() error {
-	return self.Config.GitConfig.RemoveLocalConfigValue(configdomain.KeyPerennialBranches)
+	return self.Config.NormalConfig.GitConfig.RemoveLocalConfigValue(configdomain.KeyPerennialBranches)
 }
 
 // RemoveRemote deletes the Git remote with the given name.
@@ -482,9 +522,9 @@ func (self *TestCommands) VerifyNoGitTownConfiguration() error {
 		return fmt.Errorf("unexpected Git Town configuration:\n%s", output)
 	}
 	self.Config.Reload()
-	for aliasName, aliasValue := range self.Config.Config.Aliases {
+	for aliasName, aliasValue := range self.Config.NormalConfig.Aliases {
 		if strings.HasPrefix(aliasValue, "town ") {
-			return fmt.Errorf("unexpected Git Town alias %q with value %q. All aliases: %#v", aliasName, aliasValue, self.Config.Config.Aliases)
+			return fmt.Errorf("unexpected Git Town alias %q with value %q. All aliases: %#v", aliasName, aliasValue, self.Config.NormalConfig.Aliases)
 		}
 	}
 	return nil
