@@ -20,18 +20,17 @@ import (
 // TestRuntime provides Git functionality for test code (unit and end-to-end tests).
 type TestRuntime struct {
 	commands.TestCommands
-	Config config.ValidatedConfig
 }
 
 // Clone creates a clone of the repository managed by this test.Runner into the given directory.
 // The cloned repo uses the same homeDir and binDir as its origin.
-func Clone(original *testshell.TestRunner, targetDir string) TestRuntime {
+func Clone(original *testshell.TestRunner, targetDir string) commands.TestCommands {
 	original.MustRun("git", "clone", original.WorkingDir, targetDir)
 	return New(targetDir, original.HomeDir, original.BinDir)
 }
 
 // Create creates test.Runner instances.
-func Create(t *testing.T) TestRuntime {
+func Create(t *testing.T) commands.TestCommands {
 	t.Helper()
 	dir := t.TempDir()
 	workingDir := filepath.Join(dir, "repo")
@@ -47,20 +46,20 @@ func Create(t *testing.T) TestRuntime {
 
 // CreateGitTown creates a test.Runtime for use in tests,
 // with a main branch and initial git town configuration.
-func CreateGitTown(t *testing.T) TestRuntime {
+func CreateGitTown(t *testing.T) commands.TestCommands {
 	t.Helper()
 	repo := Create(t)
 	repo.CreateBranch(gitdomain.NewLocalBranchName("main"), gitdomain.NewBranchName("initial"))
 	err := repo.Config.SetMainBranch(gitdomain.NewLocalBranchName("main"))
 	must.NoError(t, err)
-	err = repo.Config.SetPerennialBranches(gitdomain.LocalBranchNames{})
+	err = repo.Config.NormalConfig.SetPerennialBranches(gitdomain.LocalBranchNames{})
 	must.NoError(t, err)
 	return repo
 }
 
 // initialize creates a fully functioning test.Runner in the given working directory,
 // including necessary Git configuration to make commits. Creates missing folders as needed.
-func Initialize(workingDir, homeDir, binDir string) TestRuntime {
+func Initialize(workingDir, homeDir, binDir string) commands.TestCommands {
 	runtime := New(workingDir, homeDir, binDir)
 	runtime.MustRun("git", "init", "--initial-branch=initial")
 	runtime.MustRun("git", "config", "--global", "user.name", "user")
@@ -71,7 +70,7 @@ func Initialize(workingDir, homeDir, binDir string) TestRuntime {
 
 // newRuntime provides a new test.Runner instance working in the given directory.
 // The directory must contain an existing Git repo.
-func New(workingDir, homeDir, binDir string) TestRuntime {
+func New(workingDir, homeDir, binDir string) commands.TestCommands {
 	testRunner := testshell.TestRunner{
 		BinDir:           binDir,
 		HomeDir:          homeDir,
@@ -93,22 +92,11 @@ func New(workingDir, homeDir, binDir string) TestRuntime {
 		GlobalConfig: configdomain.EmptyPartialConfig(),
 		LocalConfig:  configdomain.EmptyPartialConfig(),
 	})
-	validatedConfig := config.ValidatedConfig{
-		Config: configdomain.ValidatedConfig{
-			UnvalidatedConfig: unvalidatedConfig.Config.Value,
-			GitUserEmail:      "test@test.com",
-			GitUserName:       "Tester",
-			MainBranch:        gitdomain.NewLocalBranchName("main"),
-		},
-		UnvalidatedConfig: &unvalidatedConfig,
-	}
+	unvalidatedConfig.UnvalidatedConfig.MainBranch = Some(gitdomain.NewLocalBranchName("main"))
 	testCommands := commands.TestCommands{
 		Commands:   &gitCommands,
-		Config:     validatedConfig,
+		Config:     unvalidatedConfig,
 		TestRunner: &testRunner,
 	}
-	return TestRuntime{
-		Config:       validatedConfig,
-		TestCommands: testCommands,
-	}
+	return testCommands
 }
