@@ -4,6 +4,6 @@ import (
 	"github.com/google/go-github/v58/github"
 )
 
-func issueAuthor(issue *github.Issue) string {
+func issueAuthor(issue github.Issue) string {
 	return *issue.User.Login
 }
